# On-Ramp SDK

## Getting started

- Please make sure that there is either a deployed OnRamp API service or you are running it localy.
- Install the SDK package from the archive.
- Import the on ramp sdk with this line of code: `import {OnRampSdk} from '@codefi/on-ramp-sdk'`

## On-Ramp SDK

To facilitate back-end interaction, a SDK can be used.

You can use it like this:

```typescript
const sdk: IOnRampSdk = await OnRampSdk.getSDK(
  Environment.Staging,
  Context.Mobile,
  {
    verbose: true,
    maxInstanceCount: 1,
  },
)
```

## Local Development with MetaMask Portfolio

To connect a local instance of the SDK to a local MetaMask Portfolio client, follow these steps:

### 1. Update SDK Configuration

1. Open the `tsconfig.json` file in the SDK project.
2. Modify the `module` and `moduleResolution` properties as follows:
   ```json
   {
     "compilerOptions": {
       "module": "esnext",
       "moduleResolution": "node"
       // other configurations
     }
   }
   ```

### 2. Link SDK to Portfolio

1. In the SDK project directory, run the following command to create a symbolic link:

   ```sh
   yarn link
   ```

2. In the Portfolio project directory, link the SDK by running:

   ```sh
   yarn link @consensys/on-ramp-sdk
   ```

3. Remove the cache to ensure the changes take effect:
   ```sh
   rm -rf node_modules/.cache
   ```

### 3. Install Dependencies

1. In the Portfolio project directory, install the necessary packages:
   ```sh
   yarn install
   ```

### 4. Update Vite Configuration

1. Open the `vite.config.js` file in the Portfolio project.
2. Add the following configuration to exclude the SDK from dependency optimization:
   ```js
   export default {
     // other configurations
     optimizeDeps: {
       exclude: ['@consensys/on-ramp-sdk'],
     },
   }
   ```

### 5. Rebuild After SDK Changes

Whenever you make changes to the SDK, remember to rebuild the project to reflect those changes in the Portfolio client:

```sh
yarn build
```
