import { Configuration } from './configuration';
import { AxiosPromise, AxiosInstance, AxiosRequestConfig } from 'axios';
import { RequestArgs, BaseAPI } from './base';
export interface AggregatorNetwork {
    active: boolean;
    chainId: string;
    chainName: string;
    shortName: string;
    nativeTokenSupported: boolean;
}
export interface AmbiguousCryptoCurrency {
    id: string;
    providers: Array<CryptoCurrencyProvider>;
    cryptoCurrencies: Array<CryptoCurrency>;
}
export interface ApplePayOption {
    supported: boolean;
    merchantId: string;
}
export interface BatchQuoteOrQuery {
    success: Array<QuoteOrQuery>;
    sorted: Array<QuoteSortMetadata>;
    error: Array<string>;
    customActions: Array<PaymentCustomAction>;
}
export declare const Browser: {
    readonly InAppOsBrowser: "IN_APP_OS_BROWSER";
    readonly AppBrowser: "APP_BROWSER";
    readonly ExternalOsBrowser: "EXTERNAL_OS_BROWSER";
};
export type Browser = (typeof Browser)[keyof typeof Browser];
export interface BuyWidgetInformation {
    url: string;
    browser: BuyWidgetInformationBrowserEnum;
    orderId?: string;
}
export declare const BuyWidgetInformationBrowserEnum: {
    readonly InAppOsBrowser: "IN_APP_OS_BROWSER";
    readonly AppBrowser: "APP_BROWSER";
    readonly ExternalOsBrowser: "EXTERNAL_OS_BROWSER";
};
export type BuyWidgetInformationBrowserEnum = (typeof BuyWidgetInformationBrowserEnum)[keyof typeof BuyWidgetInformationBrowserEnum];
export interface Cache {
    parameters: RegionCacheParameters;
    payments: Array<Payment>;
    fiatCurrencies: Array<FiatCurrency>;
    cryptoCurrencies: Array<CryptoCurrency>;
    limits?: Limits;
}
export interface Country {
    id: string;
    name: string;
    emoji: string;
    currencies: Array<string>;
    unsupported: boolean;
    hidden: boolean;
    states: Array<State>;
    support: CountrySupport;
    recommended: boolean;
    enableSell: boolean;
    detected: boolean;
}
export interface CountryReport {
    id: string;
    country: Country;
    state: State;
    status: SupportReport;
    providerCount: number;
    paymentCount: number;
    fiatCurrencyCount: number;
    cryptoCurrencyCount: number;
}
export interface CountryReportDetails {
    id: string;
    country: Country;
    state: State;
    status: SupportReport;
    providerCount: number;
    paymentCount: number;
    fiatCurrencyCount: number;
    cryptoCurrencyCount: number;
    supportedProviders: Array<ProviderReport>;
    supportedPayments: Array<PaymentReport>;
    supportedCryptoCurrencies: Array<CryptoCurrencyReport>;
    supportedFiatCurrencies: Array<FiatCurrencyReport>;
}
export interface CountryReportList {
    countries: Array<CountryReport>;
}
export interface CountrySupport {
    buy: boolean;
    recurringBuy: boolean;
    sell: boolean;
}
export interface CryptoCurrency {
    id: string;
    idv2: string;
    legacyId: string;
    network: Network;
    symbol: string;
    logo: string;
    decimals: number;
    address: string;
    name: string;
    limits: Array<string>;
    sellEnabled: boolean;
    assetId: string;
}
export interface CryptoCurrencyProvider {
    provider: Provider;
    status: number;
    address: string;
    chainId: string;
    providerId: string;
    assetId: string;
}
export interface CryptoCurrencyReport {
    id: string;
    cryptoCurrency: CryptoCurrency;
    status: SupportReport;
}
export interface CryptoCurrencyReportDetails {
    id: string;
    cryptoCurrency: CryptoCurrency;
    status: SupportReport;
    supportedCountries: Array<CountryReport>;
    supportedPayments: Array<PaymentReport>;
    supportedFiatCurrencies: Array<FiatCurrencyReport>;
    supportedProviders: Array<ProviderReport>;
}
export interface CryptoCurrencyReportList {
    cryptoCurrencies: Array<CryptoCurrencyReport>;
}
export interface CryptoLimits {
    maxAmount: number;
    minAmount: number;
    feeFixedRate: number;
    feeDynamicRate: number;
    payments?: Array<PaymentLimits>;
}
export interface ExcludedFiatAndPaymentMethod {
    excludedFiat: string;
    excludedPaymentMethod: string;
}
export interface FiatAmount {
    value: number;
}
export interface FiatCurrency {
    id: string;
    symbol: string;
    name: string;
    decimals: number;
    denomSymbol: string;
}
export interface FiatCurrencyReport {
    id: string;
    fiatCurrency: FiatCurrency;
    status: SupportReport;
}
export interface FiatCurrencyReportDetails {
    id: string;
    fiatCurrency: FiatCurrency;
    status: SupportReport;
    supportedCountries: Array<CountryReport>;
    supportedPayments: Array<PaymentReport>;
    supportedCryptoCurrencies: Array<CryptoCurrencyReport>;
    supportedProviders: Array<ProviderReport>;
}
export interface FiatCurrencyReportList {
    fiatCurrencies: Array<FiatCurrencyReport>;
}
export interface GenericConfigurationReport {
    date: string;
    raw: object;
    errors: Array<string>;
}
export interface Image {
    url: string;
    label?: string;
    height: number;
    width: number;
}
export interface InlineResponse200 {
    status?: string;
    info?: {
        [key: string]: {
            [key: string]: object;
        };
    } | null;
    error?: {
        [key: string]: {
            [key: string]: object;
        };
    } | null;
    details?: {
        [key: string]: {
            [key: string]: object;
        };
    };
}
export interface InlineResponse503 {
    status?: string;
    info?: {
        [key: string]: {
            [key: string]: object;
        };
    } | null;
    error?: {
        [key: string]: {
            [key: string]: object;
        };
    } | null;
    details?: {
        [key: string]: {
            [key: string]: object;
        };
    };
}
export interface Limits {
    maxAmount: number;
    minAmount: number;
    feeFixedRate: number;
    feeDynamicRate: number;
}
export interface Link {
    name: string;
    url: string;
}
export interface Logos {
    light: string;
    dark: string;
    height: number;
    width: number;
}
export interface Metadata {
    product: string;
    service: string;
    version: string;
    features: Array<string>;
}
export interface Network {
    active: boolean;
    chainId: string;
    chainName: string;
    shortName: string;
}
export interface NetworkDetails {
    chainId: string;
    nickname: string;
    rpcUrl: string;
    ticker: string;
    rpcPrefs: RPCPrefs;
    isEvm: boolean;
}
export interface Order {
    id: string;
    isOnlyLink: boolean;
    provider: Provider;
    success: boolean;
    cryptoAmount: number | string;
    fiatAmount: number;
    cryptoCurrency: CryptoCurrency;
    fiatCurrency: FiatCurrency;
    providerOrderId: string;
    providerOrderLink: string;
    createdAt: number;
    paymentMethod: Payment;
    totalFeesFiat: number;
    txHash: string;
    walletAddress: string;
    status: OrderStatusEnum;
    network: string;
    canBeUpdated: boolean;
    idHasExpired: boolean;
    idExpirationDate: number;
    excludeFromPurchases: boolean;
    timeDescriptionPending: string;
    fiatAmountInUsd: number;
    feesInUsd: number;
    region: string;
    orderType: OrderOrderTypeEnum;
    exchangeRate?: number;
    context: string;
    recurring?: OrderRecurringInformation;
    pollingSecondsMinimum?: number;
    statusDescription?: string;
}
export declare const OrderStatusEnum: {
    readonly Unknown: "UNKNOWN";
    readonly Precreated: "PRECREATED";
    readonly Created: "CREATED";
    readonly Pending: "PENDING";
    readonly Failed: "FAILED";
    readonly Completed: "COMPLETED";
    readonly Cancelled: "CANCELLED";
    readonly IdExpired: "ID_EXPIRED";
};
export type OrderStatusEnum = (typeof OrderStatusEnum)[keyof typeof OrderStatusEnum];
export declare const OrderOrderTypeEnum: {
    readonly Buy: "BUY";
    readonly Transfer: "TRANSFER";
    readonly Sell: "SELL";
};
export type OrderOrderTypeEnum = (typeof OrderOrderTypeEnum)[keyof typeof OrderOrderTypeEnum];
export interface OrderId {
    id: string;
}
export interface OrderLink {
    id: string;
    isOnlyLink: boolean;
    provider: Provider;
    providerOrderLink: string;
    canBeUpdated: boolean;
}
export interface OrderRecurringInformation {
    isActive: boolean;
    firstOrderId: string;
}
export interface PartnerPurchase {
    bankId: string;
    createdAt: string;
    updatedAt: string;
    cryptoAmount: number;
    cryptoId: string;
    fiatAmount: number;
    fiatId: string;
    usdValue: number;
    id: string;
    customId: string;
    paymentMethodId: string;
    context: string;
    status: string;
    statusReason: string;
    userId: string;
    walletAddress: string;
    provider: string;
    partnerFees: number;
    networkFees: number;
    processingFees: number;
    exchangeRate: number;
    txHash: string;
    providerPayment: string;
    statusCode: string;
    orderType: string;
    link: string;
    region: string;
}
export interface Payment {
    id: string;
    paymentType: PaymentType;
    name: string;
    icons: Array<PaymentIcon>;
    logo: PaymentLogo;
    detail: string;
    disclaimer: string;
    score: number;
    delay: Array<number>;
    amountTier: Array<number>;
    isApplePay: boolean;
    translation: string;
    supportedCurrency: Array<string>;
    supportedRegions: Array<string>;
    customAction: PaymentCustomAction;
    browser: Browser;
    pendingOrderDescription: string;
    sellEnabled: boolean;
    contextSpecificDetails: object;
}
export interface PaymentCustomAction {
    buy: PaymentCustomActionBuy;
    button: PaymentCustomActionButton;
    buyButton: PaymentCustomActionButton;
    sellButton: PaymentCustomActionButton;
    supportedPaymentMethodIds: Array<string>;
    paymentMethodId: string;
}
export interface PaymentCustomActionButton {
    light: PaymentCustomActionButtonTheme;
    dark: PaymentCustomActionButtonTheme;
}
export interface PaymentCustomActionButtonTheme {
    value: Array<TextOrImage>;
    backgroundColor: string;
    textColor: string;
    hover?: object;
}
export interface PaymentCustomActionBuy {
    providerId: string;
    provider: Provider;
}
export interface PaymentFeature {
    enabled: boolean;
}
export interface PaymentIcon {
    type: PaymentIconType;
    name: string;
}
export declare const PaymentIconType: {
    readonly AntDesign: "antDesign";
    readonly Entypo: "entypo";
    readonly EvilIcons: "evilIcons";
    readonly Feather: "feather";
    readonly FontAwesome: "fontAwesome";
    readonly FontAwesome5: "fontAwesome5";
    readonly Fontisto: "fontisto";
    readonly Foundation: "foundation";
    readonly Ionicons: "ionicons";
    readonly MaterialIcons: "materialIcons";
    readonly MaterialCommunityIcons: "materialCommunityIcons";
    readonly Octicons: "octicons";
    readonly Zocial: "zocial";
    readonly SimpleLineIcons: "simpleLineIcons";
};
export type PaymentIconType = (typeof PaymentIconType)[keyof typeof PaymentIconType];
export interface PaymentLimits {
    maxAmount: number;
    minAmount: number;
    feeFixedRate: number;
    feeDynamicRate: number;
    payment: string;
}
export interface PaymentLogo {
    light: Array<string>;
    dark: Array<string>;
}
export interface PaymentReport {
    id: string;
    payment: Payment;
    status: SupportReport;
}
export interface PaymentReportDetails {
    id: string;
    payment: Payment;
    status: SupportReport;
    supportedProviders: Array<ProviderReport>;
    supportedCountries: Array<CountryReport>;
    supportedCryptoCurrencies: Array<CryptoCurrencyReport>;
    supportedFiatCurrencies: Array<FiatCurrencyReport>;
}
export interface PaymentReportList {
    payments: Array<PaymentReport>;
}
export declare const PaymentType: {
    readonly DebitCreditCard: "debit-credit-card";
    readonly BankTransfer: "bank-transfer";
    readonly ApplePay: "apple-pay";
    readonly GooglePay: "google-pay";
    readonly RevPay: "rev-pay";
    readonly Wallet: "wallet";
};
export type PaymentType = (typeof PaymentType)[keyof typeof PaymentType];
export interface Provider {
    id: string;
    logos: Logos;
    name: string;
    description: string;
    hqAddress: string;
    links: Array<Link>;
    features: ProviderFeatures;
    environmentType: ProviderEnvironmentTypeEnum;
}
export declare const ProviderEnvironmentTypeEnum: {
    readonly Staging: "STAGING";
    readonly Production: "PRODUCTION";
};
export type ProviderEnvironmentTypeEnum = (typeof ProviderEnvironmentTypeEnum)[keyof typeof ProviderEnvironmentTypeEnum];
export interface ProviderBuyFeature {
    enabled: boolean;
    userAgent: string;
    padCustomOrderId: boolean;
    orderCustomIdRequired: boolean;
    orderCustomId: ProviderBuyFeatureOrderCustomIdEnum;
    orderCustomIdPrefixes: Array<string>;
    orderCustomIdExpiration: number;
    orderCustomIdSeparator: string;
    browser: ProviderBuyFeatureBrowserEnum;
    supportedByBackend: boolean;
    redirection: ProviderBuyFeatureRedirectionEnum;
}
export declare const ProviderBuyFeatureOrderCustomIdEnum: {
    readonly Empty: "";
    readonly Digits10: "DIGITS_10";
    readonly Guid: "GUID";
    readonly Alpha64: "ALPHA_64";
};
export type ProviderBuyFeatureOrderCustomIdEnum = (typeof ProviderBuyFeatureOrderCustomIdEnum)[keyof typeof ProviderBuyFeatureOrderCustomIdEnum];
export declare const ProviderBuyFeatureBrowserEnum: {
    readonly InAppOsBrowser: "IN_APP_OS_BROWSER";
    readonly AppBrowser: "APP_BROWSER";
    readonly ExternalOsBrowser: "EXTERNAL_OS_BROWSER";
};
export type ProviderBuyFeatureBrowserEnum = (typeof ProviderBuyFeatureBrowserEnum)[keyof typeof ProviderBuyFeatureBrowserEnum];
export declare const ProviderBuyFeatureRedirectionEnum: {
    readonly HttpRedirection: "HTTP_REDIRECTION";
    readonly JsonRedirection: "JSON_REDIRECTION";
};
export type ProviderBuyFeatureRedirectionEnum = (typeof ProviderBuyFeatureRedirectionEnum)[keyof typeof ProviderBuyFeatureRedirectionEnum];
export interface ProviderFeatures {
    buy: ProviderBuyFeature;
    recurringBuy: ProviderRecurringBuyFeature;
    quotes: ProviderQuoteFeature;
    sell?: ProviderSellFeature;
    sellQuotes?: ProviderSellQuoteFeature;
}
export interface ProviderQuote {
    fiatCurrency: string;
    cryptoCurrency: string;
    paymentMethod: Array<string>;
}
export interface ProviderQuoteFeature {
    enabled: boolean;
    supportedByBackend: boolean;
}
export interface ProviderRecurringBuyFeature {
    enabled: boolean;
}
export interface ProviderReport {
    id: string;
    name: string;
    environment: string;
    isGeneric: boolean;
    status: SupportReport;
    provider: Provider;
}
export interface ProviderReportConfigurationItem {
    label: string;
    description: string;
    value: string;
    valueDescription: string;
}
export interface ProviderReportCountry {
    id: string;
    country: CountryReport;
}
export interface ProviderReportCryptoCurrency {
    id: string;
    network: string;
    address: string;
    cryptoCurrency: CryptoCurrencyReport;
}
export interface ProviderReportDetails {
    id: string;
    name: string;
    environment: string;
    isGeneric: boolean;
    status: SupportReport;
    provider: Provider;
    privateConfiguration: ProviderReportPrivateConfiguration;
    supportedCountries: Array<CountryReport>;
    supportedPayments: Array<PaymentReport>;
    supportedCryptoCurrencies: Array<CryptoCurrencyReport>;
    supportedFiatCurrencies: Array<FiatCurrencyReport>;
    genericConfiguration: GenericConfigurationReport;
    declaredCryptoCurrencies: Array<ProviderReportCryptoCurrency>;
    declaredFiatCurrencies: Array<ProviderReportFiatCurrency>;
    declaredPayments: Array<ProviderReportPayment>;
    declaredCountries: Array<ProviderReportCountry>;
}
export interface ProviderReportFiatCurrency {
    id: string;
    fiatCurrency: FiatCurrencyReport;
}
export interface ProviderReportList {
    providers: Array<ProviderReport>;
}
export interface ProviderReportPayment {
    id: string;
    payment: PaymentReport;
}
export interface ProviderReportPrivateConfiguration {
    items: Array<ProviderReportConfigurationItem>;
}
export interface ProviderSellFeature {
    enabled: boolean;
}
export interface ProviderSellQuoteFeature {
    enabled: boolean;
}
export interface ProviderSupportedCryptoCurrency {
    id: string;
    translation: string;
    specificNetworkId: string;
    limits: CryptoLimits;
    excludedFiat: Array<string>;
    excludedFiatAndPaymentMethods: Array<ExcludedFiatAndPaymentMethod>;
    sell?: ProviderSupportedCryptoCurrencySell;
    recurringBuy?: ProviderSupportedCryptoCurrencyRecurringBuy;
}
export interface ProviderSupportedCryptoCurrencyRecurringBuy {
    enabled: boolean;
    limits: Limits;
}
export interface ProviderSupportedCryptoCurrencySell {
    enabled: boolean;
    limits: Limits;
}
export interface ProviderSupportedFiatCurrency {
    id: string;
    translation: string;
    limits: {
        [key: string]: Limits;
    };
    excludedPaymentMethods: Array<string>;
    sell?: ProviderSupportedFiatCurrencySell;
    recurringBuy?: ProviderSupportedFiatCurrencyRecurringBuy;
}
export interface ProviderSupportedFiatCurrencyRecurringBuy {
    enabled: boolean;
}
export interface ProviderSupportedFiatCurrencySell {
    enabled: boolean;
}
export interface PurchaseOrder {
    id: string;
    customId: string;
    userId: string;
    link: string;
    crypto: object;
    fiatAmountIn: number;
    fiatAmountInUsd: number;
    cryptoAmount: number;
    fiat: string;
    payment: string;
    providerPayment: string;
    exchangeRate: string;
    processingFees: Array<string>;
    networkFees: Array<string>;
    partnerFees: Array<string>;
    createdAt: string;
    updatedAt: string;
    transactionHash: string;
    walletAddress: string;
    status: string;
    statusCode: string;
    statusReason: string;
    partnerAccountId: string;
    orderType: string;
}
export interface PurchasesResponse {
    purchases?: Array<PartnerPurchase>;
    links: PurchasesResponseLinks;
}
export interface PurchasesResponseLinks {
    self: string;
    previous?: string;
    next?: string;
}
export interface Quote {
    crypto: CryptoCurrency;
    cryptoId: string;
    cryptoTranslation?: string;
    fiat: FiatCurrency;
    fiatId: string;
    networkFee: number;
    providerFee: number;
    extraFee: number;
    amountIn: number | string;
    amountOut: number;
    exchangeRate?: number;
    status: number;
    message: string;
    error: boolean;
    paymentMethod: object;
    receiver: string;
    isCustomAction: boolean;
    bestRate: boolean;
}
export interface QuoteMetadata {
    reliability: number;
    tags: QuoteTags;
}
export interface QuoteOrQuery {
    url: string;
    method: string;
    headers: object;
    provider: string;
    providerInfo: Provider;
    providerQuote: ProviderQuote;
    quote: Quote;
    nativeApplePay: ApplePayOption;
    metadata: QuoteMetadata;
}
export interface QuoteSortMetadata {
    sortBy: QuoteSortMetadataSortByEnum;
    ids: Array<string>;
}
export declare const QuoteSortMetadataSortByEnum: {
    readonly _0: "0";
    readonly _1: "1";
    readonly _2: "2";
};
export type QuoteSortMetadataSortByEnum = (typeof QuoteSortMetadataSortByEnum)[keyof typeof QuoteSortMetadataSortByEnum];
export interface QuoteTags {
    isBestRate: boolean;
    isMostReliable: boolean;
}
export interface RPCPrefs {
    blockExplorerUrl: string;
    imageUrl: string;
}
export interface RankingInformation {
    providerRankings: string;
    previousWeight: number;
    paymentWeight: number;
}
export interface RecurringOrders {
    orders: Array<Order>;
    links: RecurringOrdersLinks;
}
export interface RecurringOrdersLinks {
    self: string;
    previous: string;
    next: string;
}
export interface RegionCache {
    parameters: RegionCacheParameters;
    payments: Array<RegionPayment>;
    fiatCurrencies: Array<RegionFiatCurrency>;
    cryptoCurrencies: Array<RegionCryptoCurrency>;
    providers: Array<RegionProvider>;
}
export interface RegionCacheParameters {
    appleMerchantId: string;
    disableLimits: boolean;
    defaultOrderCustomIdSeparator: string;
}
export interface RegionCryptoCurrency {
    cryptoCurrency: CryptoCurrency;
    excludedPaymentMethods: Array<string>;
    excludedFiat: Array<string>;
    excludedFiatAndPaymentMethods: Array<ExcludedFiatAndPaymentMethod>;
    sell: RegionCryptoCurrencyFeature;
    recurringBuy: RegionCryptoCurrencyFeature;
}
export interface RegionCryptoCurrencyFeature {
    enabled: boolean;
    excludedPaymentMethods: Array<string>;
    excludedFiat: Array<string>;
    excludedFiatAndPaymentMethods: Array<ExcludedFiatAndPaymentMethod>;
}
export interface RegionFiatCurrency {
    fiatCurrency: FiatCurrency;
    excludedPaymentMethods: Array<string>;
    sell: RegionFiatCurrencyFeature;
    recurringBuy: RegionFiatCurrencyFeature;
}
export interface RegionFiatCurrencyFeature {
    enabled: boolean;
    excludedPaymentMethods: Array<string>;
}
export interface RegionPayment {
    id: string;
    paymentType: PaymentType;
    name: string;
    icons: Array<PaymentIcon>;
    logo: PaymentLogo;
    detail: string;
    disclaimer: string;
    score: number;
    delay: Array<number>;
    amountTier: Array<number>;
    isApplePay: boolean;
    translation: string;
    supportedCurrency: Array<string>;
    supportedRegions: Array<string>;
    customAction: PaymentCustomAction;
    browser: Browser;
    pendingOrderDescription: string;
    sellEnabled: boolean;
    contextSpecificDetails: object;
    sell: PaymentFeature;
    buy: PaymentFeature;
    recurringBuy: PaymentFeature;
}
export interface RegionProvider {
    provider: Provider;
    supportedCryptoCurrencies: Array<ProviderSupportedCryptoCurrency>;
    supportedFiatCurrencies: Array<ProviderSupportedFiatCurrency>;
    supportedPaymentMethods: Array<Payment>;
    quote: string;
    sellQuote: string;
    quoteTransformation: object;
    sellQuoteTransformation: object;
    data: object;
    sell?: RegionProviderSell;
    recurringBuy?: RegionProviderRecurringBuy;
}
export interface RegionProviderRecurringBuy {
    enabled: boolean;
    supportedCryptoCurrencies: Array<ProviderSupportedCryptoCurrency>;
    supportedFiatCurrencies: Array<ProviderSupportedFiatCurrency>;
    supportedPaymentMethods: Array<Payment>;
}
export interface RegionProviderSell {
    supportedCryptoCurrencies: Array<ProviderSupportedCryptoCurrency>;
    supportedFiatCurrencies: Array<ProviderSupportedFiatCurrency>;
    supportedPaymentMethods: Array<Payment>;
}
export interface SellOrder {
    id: string;
    isOnlyLink: boolean;
    provider: Provider;
    success: boolean;
    cryptoAmount: string;
    fiatAmount: number;
    cryptoCurrency: CryptoCurrency;
    fiatCurrency: FiatCurrency;
    providerOrderId: string;
    providerOrderLink: string;
    createdAt: number;
    paymentMethod: Payment;
    totalFeesFiat: number;
    txHash: string;
    walletAddress: string;
    status: SellOrderStatusEnum;
    network: string;
    canBeUpdated: boolean;
    idHasExpired: boolean;
    idExpirationDate: number;
    excludeFromPurchases: boolean;
    timeDescriptionPending: string;
    fiatAmountInUsd: number;
    feesInUsd: number;
    orderType: SellOrderOrderTypeEnum;
    exchangeRate?: number;
    context: string;
    depositWallet: string;
    pollingSecondsMinimum?: number;
    statusDescription?: string;
    region: string;
}
export declare const SellOrderStatusEnum: {
    readonly Unknown: "UNKNOWN";
    readonly Precreated: "PRECREATED";
    readonly Created: "CREATED";
    readonly Pending: "PENDING";
    readonly Failed: "FAILED";
    readonly Completed: "COMPLETED";
    readonly Cancelled: "CANCELLED";
    readonly IdExpired: "ID_EXPIRED";
};
export type SellOrderStatusEnum = (typeof SellOrderStatusEnum)[keyof typeof SellOrderStatusEnum];
export declare const SellOrderOrderTypeEnum: {
    readonly Sell: "SELL";
};
export type SellOrderOrderTypeEnum = (typeof SellOrderOrderTypeEnum)[keyof typeof SellOrderOrderTypeEnum];
export interface State {
    id: string;
    name: string;
    unsupported: boolean;
    support: CountrySupport;
    recommended: boolean;
    detected: boolean;
    stateId?: string;
}
export interface SupportReport {
    enabled: boolean;
    reason: string;
}
export interface SupportedNetworks {
    networks: Array<AggregatorNetwork>;
}
export interface SystemReport {
    ambiguousCryptoCurrencies: Array<AmbiguousCryptoCurrency>;
}
export interface TextOrImage {
    image: Image;
    text: string;
}
export declare const AnalyticsApiAxiosParamCreator: (configuration?: Configuration) => {
    analyticsControllerGetCountryReport: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetCryptoReport: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetFiatReport: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetNetworkReport: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetPartnerPurchases: (start: string, end: string, providerCode: string, skip?: number, limit?: number, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetPaymentReport: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetProviderReport: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetSupportedCountriesByProvider: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetSupportedCryptoCurrencies: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    analyticsControllerGetSupportedRegionsByProvider: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
export declare const AnalyticsApiFp: (configuration?: Configuration) => {
    analyticsControllerGetCountryReport(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    analyticsControllerGetCryptoReport(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    analyticsControllerGetFiatReport(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    analyticsControllerGetNetworkReport(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    analyticsControllerGetPartnerPurchases(start: string, end: string, providerCode: string, skip?: number, limit?: number, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<PurchasesResponse>>;
    analyticsControllerGetPaymentReport(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    analyticsControllerGetProviderReport(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    analyticsControllerGetSupportedCountriesByProvider(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    analyticsControllerGetSupportedCryptoCurrencies(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<Array<CryptoCurrency>>>;
    analyticsControllerGetSupportedRegionsByProvider(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
};
export declare const AnalyticsApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    analyticsControllerGetCountryReport(options?: any): AxiosPromise<object>;
    analyticsControllerGetCryptoReport(options?: any): AxiosPromise<object>;
    analyticsControllerGetFiatReport(options?: any): AxiosPromise<object>;
    analyticsControllerGetNetworkReport(options?: any): AxiosPromise<object>;
    analyticsControllerGetPartnerPurchases(start: string, end: string, providerCode: string, skip?: number, limit?: number, options?: any): AxiosPromise<PurchasesResponse>;
    analyticsControllerGetPaymentReport(options?: any): AxiosPromise<object>;
    analyticsControllerGetProviderReport(options?: any): AxiosPromise<object>;
    analyticsControllerGetSupportedCountriesByProvider(options?: any): AxiosPromise<object>;
    analyticsControllerGetSupportedCryptoCurrencies(options?: any): AxiosPromise<Array<CryptoCurrency>>;
    analyticsControllerGetSupportedRegionsByProvider(options?: any): AxiosPromise<object>;
};
export declare class AnalyticsApi extends BaseAPI {
    analyticsControllerGetCountryReport(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    analyticsControllerGetCryptoReport(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    analyticsControllerGetFiatReport(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    analyticsControllerGetNetworkReport(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    analyticsControllerGetPartnerPurchases(start: string, end: string, providerCode: string, skip?: number, limit?: number, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<PurchasesResponse, any>>;
    analyticsControllerGetPaymentReport(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    analyticsControllerGetProviderReport(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    analyticsControllerGetSupportedCountriesByProvider(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    analyticsControllerGetSupportedCryptoCurrencies(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<CryptoCurrency[], any>>;
    analyticsControllerGetSupportedRegionsByProvider(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
}
export declare const CurrenciesApiAxiosParamCreator: (configuration?: Configuration) => {
    currenciesControllerGetCryptoRate: (chainId: string, cryptoCode: string, fiat: string, value?: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
export declare const CurrenciesApiFp: (configuration?: Configuration) => {
    currenciesControllerGetCryptoRate(chainId: string, cryptoCode: string, fiat: string, value?: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<FiatAmount>>;
};
export declare const CurrenciesApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    currenciesControllerGetCryptoRate(chainId: string, cryptoCode: string, fiat: string, value?: string, context?: string, options?: any): AxiosPromise<FiatAmount>;
};
export declare class CurrenciesApi extends BaseAPI {
    currenciesControllerGetCryptoRate(chainId: string, cryptoCode: string, fiat: string, value?: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<FiatAmount, any>>;
}
export declare const DefaultApiAxiosParamCreator: (configuration?: Configuration) => {
    dependencyControllerGetAllDependencies: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    eligibilityControllerGetCardEligibility: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    eligibilityControllerGetCardEligibilitySimple: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    eligibilityControllerSubmitUniqueLink: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    eligibilityControllerValidateUniqueLink: (id: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    monitoringControllerGetPrometheusMetrics: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
export declare const DefaultApiFp: (configuration?: Configuration) => {
    dependencyControllerGetAllDependencies(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    eligibilityControllerGetCardEligibility(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    eligibilityControllerGetCardEligibilitySimple(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<boolean>>;
    eligibilityControllerSubmitUniqueLink(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<void>>;
    eligibilityControllerValidateUniqueLink(id: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<void>>;
    monitoringControllerGetPrometheusMetrics(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<void>>;
};
export declare const DefaultApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    dependencyControllerGetAllDependencies(options?: any): AxiosPromise<object>;
    eligibilityControllerGetCardEligibility(options?: any): AxiosPromise<object>;
    eligibilityControllerGetCardEligibilitySimple(options?: any): AxiosPromise<boolean>;
    eligibilityControllerSubmitUniqueLink(options?: any): AxiosPromise<void>;
    eligibilityControllerValidateUniqueLink(id: string, options?: any): AxiosPromise<void>;
    monitoringControllerGetPrometheusMetrics(options?: any): AxiosPromise<void>;
};
export declare class DefaultApi extends BaseAPI {
    dependencyControllerGetAllDependencies(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    eligibilityControllerGetCardEligibility(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    eligibilityControllerGetCardEligibilitySimple(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<boolean, any>>;
    eligibilityControllerSubmitUniqueLink(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<void, any>>;
    eligibilityControllerValidateUniqueLink(id: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<void, any>>;
    monitoringControllerGetPrometheusMetrics(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<void, any>>;
}
export declare const HealthApiAxiosParamCreator: (configuration?: Configuration) => {
    healthControllerCheck: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    metadataControllerGetMetadata: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
export declare const HealthApiFp: (configuration?: Configuration) => {
    healthControllerCheck(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<InlineResponse200>>;
    metadataControllerGetMetadata(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<Metadata>>;
};
export declare const HealthApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    healthControllerCheck(options?: any): AxiosPromise<InlineResponse200>;
    metadataControllerGetMetadata(options?: any): AxiosPromise<Metadata>;
};
export declare class HealthApi extends BaseAPI {
    healthControllerCheck(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<InlineResponse200, any>>;
    metadataControllerGetMetadata(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<Metadata, any>>;
}
export declare const OrderManagementApiAxiosParamCreator: (configuration?: Configuration) => {
    ordersControllerGetAllProviders: (environment?: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetAllQuotes: (regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetAllSellQuotes: (regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetBuyUrl: (providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, orderId: string, redirectUrl: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetOrder: (providerCode: string, orderCode: string, wallet: string, fromRedirection?: boolean, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetOrderIdFromCallback: (providerCode: string, url: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetQuote: (providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetRankings: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetRecurringOrders: (providerCode: string, orderCode: string, wallet: string, start: string, end: string, skip: number, limit: number, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetSellOrder: (providerCode: string, orderCode: string, wallet: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetSellOrderIdFromCallback: (providerCode: string, url: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetSellQuote: (providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerGetSellUrl: (providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, orderId: string, redirectUrl: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerRedirect: (providerCode: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    ordersControllerSubmitApplePayOrder: (providerCode: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
export declare const OrderManagementApiFp: (configuration?: Configuration) => {
    ordersControllerGetAllProviders(environment?: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<object>>;
    ordersControllerGetAllQuotes(regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<BatchQuoteOrQuery>>;
    ordersControllerGetAllSellQuotes(regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<BatchQuoteOrQuery>>;
    ordersControllerGetBuyUrl(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, orderId: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<BuyWidgetInformation>>;
    ordersControllerGetOrder(providerCode: string, orderCode: string, wallet: string, fromRedirection?: boolean, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<Order>>;
    ordersControllerGetOrderIdFromCallback(providerCode: string, url: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrderId>>;
    ordersControllerGetQuote(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<QuoteOrQuery>>;
    ordersControllerGetRankings(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<RankingInformation>>;
    ordersControllerGetRecurringOrders(providerCode: string, orderCode: string, wallet: string, start: string, end: string, skip: number, limit: number, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<RecurringOrders>>;
    ordersControllerGetSellOrder(providerCode: string, orderCode: string, wallet: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<SellOrder>>;
    ordersControllerGetSellOrderIdFromCallback(providerCode: string, url: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<OrderId>>;
    ordersControllerGetSellQuote(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<QuoteOrQuery>>;
    ordersControllerGetSellUrl(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, orderId: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<BuyWidgetInformation>>;
    ordersControllerRedirect(providerCode: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<string>>;
    ordersControllerSubmitApplePayOrder(providerCode: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<PurchaseOrder>>;
};
export declare const OrderManagementApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    ordersControllerGetAllProviders(environment?: string, context?: string, options?: any): AxiosPromise<object>;
    ordersControllerGetAllQuotes(regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: any): AxiosPromise<BatchQuoteOrQuery>;
    ordersControllerGetAllSellQuotes(regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: any): AxiosPromise<BatchQuoteOrQuery>;
    ordersControllerGetBuyUrl(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, orderId: string, redirectUrl: string, options?: any): AxiosPromise<BuyWidgetInformation>;
    ordersControllerGetOrder(providerCode: string, orderCode: string, wallet: string, fromRedirection?: boolean, context?: string, options?: any): AxiosPromise<Order>;
    ordersControllerGetOrderIdFromCallback(providerCode: string, url: string, context?: string, options?: any): AxiosPromise<OrderId>;
    ordersControllerGetQuote(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, options?: any): AxiosPromise<QuoteOrQuery>;
    ordersControllerGetRankings(options?: any): AxiosPromise<RankingInformation>;
    ordersControllerGetRecurringOrders(providerCode: string, orderCode: string, wallet: string, start: string, end: string, skip: number, limit: number, context?: string, options?: any): AxiosPromise<RecurringOrders>;
    ordersControllerGetSellOrder(providerCode: string, orderCode: string, wallet: string, context?: string, options?: any): AxiosPromise<SellOrder>;
    ordersControllerGetSellOrderIdFromCallback(providerCode: string, url: string, context?: string, options?: any): AxiosPromise<OrderId>;
    ordersControllerGetSellQuote(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, options?: any): AxiosPromise<QuoteOrQuery>;
    ordersControllerGetSellUrl(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, orderId: string, redirectUrl: string, options?: any): AxiosPromise<BuyWidgetInformation>;
    ordersControllerRedirect(providerCode: string, context?: string, options?: any): AxiosPromise<string>;
    ordersControllerSubmitApplePayOrder(providerCode: string, options?: any): AxiosPromise<PurchaseOrder>;
};
export declare class OrderManagementApi extends BaseAPI {
    ordersControllerGetAllProviders(environment?: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<object, any>>;
    ordersControllerGetAllQuotes(regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<BatchQuoteOrQuery, any>>;
    ordersControllerGetAllSellQuotes(regionId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, providers: Array<string>, providerCode: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<BatchQuoteOrQuery, any>>;
    ordersControllerGetBuyUrl(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, orderId: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<BuyWidgetInformation, any>>;
    ordersControllerGetOrder(providerCode: string, orderCode: string, wallet: string, fromRedirection?: boolean, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<Order, any>>;
    ordersControllerGetOrderIdFromCallback(providerCode: string, url: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<OrderId, any>>;
    ordersControllerGetQuote(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, amount: number, walletAddress: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<QuoteOrQuery, any>>;
    ordersControllerGetRankings(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<RankingInformation, any>>;
    ordersControllerGetRecurringOrders(providerCode: string, orderCode: string, wallet: string, start: string, end: string, skip: number, limit: number, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<RecurringOrders, any>>;
    ordersControllerGetSellOrder(providerCode: string, orderCode: string, wallet: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<SellOrder, any>>;
    ordersControllerGetSellOrderIdFromCallback(providerCode: string, url: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<OrderId, any>>;
    ordersControllerGetSellQuote(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<QuoteOrQuery, any>>;
    ordersControllerGetSellUrl(providerCode: string, regionId: string, paymentMethodId: string, cryptoCurrencyId: string, fiatCurrencyId: string, walletAddress: string, orderId: string, redirectUrl: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<BuyWidgetInformation, any>>;
    ordersControllerRedirect(providerCode: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<string, any>>;
    ordersControllerSubmitApplePayOrder(providerCode: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<PurchaseOrder, any>>;
}
export declare const RegionsApiAxiosParamCreator: (configuration?: Configuration) => {
    regionsControllerFakeCallback: (fakeRedirectCallback?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    regionsControllerGetCountries: (context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    regionsControllerGetNetworkDetails: (context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    regionsControllerGetNetworks: (context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    regionsControllerGetRegion: (regionCode: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    regionsControllerGetRegionLight: (action: string, regionCode: string, payment: Array<string>, fiat: string, crypto: string, context?: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
export declare const RegionsApiFp: (configuration?: Configuration) => {
    regionsControllerFakeCallback(fakeRedirectCallback?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<string>>;
    regionsControllerGetCountries(context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<Array<Country>>>;
    regionsControllerGetNetworkDetails(context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<NetworkDetails>>;
    regionsControllerGetNetworks(context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<SupportedNetworks>>;
    regionsControllerGetRegion(regionCode: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<RegionCache>>;
    regionsControllerGetRegionLight(action: string, regionCode: string, payment: Array<string>, fiat: string, crypto: string, context?: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<Cache>>;
};
export declare const RegionsApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    regionsControllerFakeCallback(fakeRedirectCallback?: string, options?: any): AxiosPromise<string>;
    regionsControllerGetCountries(context?: string, options?: any): AxiosPromise<Array<Country>>;
    regionsControllerGetNetworkDetails(context?: string, options?: any): AxiosPromise<NetworkDetails>;
    regionsControllerGetNetworks(context?: string, options?: any): AxiosPromise<SupportedNetworks>;
    regionsControllerGetRegion(regionCode: string, context?: string, options?: any): AxiosPromise<RegionCache>;
    regionsControllerGetRegionLight(action: string, regionCode: string, payment: Array<string>, fiat: string, crypto: string, context?: string, options?: any): AxiosPromise<Cache>;
};
export declare class RegionsApi extends BaseAPI {
    regionsControllerFakeCallback(fakeRedirectCallback?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<string, any>>;
    regionsControllerGetCountries(context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<Country[], any>>;
    regionsControllerGetNetworkDetails(context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<NetworkDetails, any>>;
    regionsControllerGetNetworks(context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<SupportedNetworks, any>>;
    regionsControllerGetRegion(regionCode: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<RegionCache, any>>;
    regionsControllerGetRegionLight(action: string, regionCode: string, payment: Array<string>, fiat: string, crypto: string, context?: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<Cache, any>>;
}
export declare const ReportsApiAxiosParamCreator: (configuration?: Configuration) => {
    reportsControllerGetCountries: (providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetCountry: (regionCode: string, providers: Array<string>, countryCode: string, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetCryptoCurrencies: (providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetCryptoCurrency: (cryptoNetwork: string, cryptoAddress: string, providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetFiatCurrencies: (providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetFiatCurrency: (fiatCode: string, providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetPayment: (paymentCode: string, providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetPayments: (providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetProvider: (providerCode: string, providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetProviders: (providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetRegions: (providers: Array<string>, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    reportsControllerGetSystem: (options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
export declare const ReportsApiFp: (configuration?: Configuration) => {
    reportsControllerGetCountries(providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CountryReportList>>;
    reportsControllerGetCountry(regionCode: string, providers: Array<string>, countryCode: string, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CountryReportDetails>>;
    reportsControllerGetCryptoCurrencies(providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CryptoCurrencyReportList>>;
    reportsControllerGetCryptoCurrency(cryptoNetwork: string, cryptoAddress: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CryptoCurrencyReportDetails>>;
    reportsControllerGetFiatCurrencies(providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<FiatCurrencyReportList>>;
    reportsControllerGetFiatCurrency(fiatCode: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<FiatCurrencyReportDetails>>;
    reportsControllerGetPayment(paymentCode: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<PaymentReportDetails>>;
    reportsControllerGetPayments(providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<PaymentReportList>>;
    reportsControllerGetProvider(providerCode: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProviderReportDetails>>;
    reportsControllerGetProviders(providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<ProviderReportList>>;
    reportsControllerGetRegions(providers: Array<string>, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CountryReportList>>;
    reportsControllerGetSystem(options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<SystemReport>>;
};
export declare const ReportsApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    reportsControllerGetCountries(providers: Array<string>, options?: any): AxiosPromise<CountryReportList>;
    reportsControllerGetCountry(regionCode: string, providers: Array<string>, countryCode: string, options?: any): AxiosPromise<CountryReportDetails>;
    reportsControllerGetCryptoCurrencies(providers: Array<string>, options?: any): AxiosPromise<CryptoCurrencyReportList>;
    reportsControllerGetCryptoCurrency(cryptoNetwork: string, cryptoAddress: string, providers: Array<string>, options?: any): AxiosPromise<CryptoCurrencyReportDetails>;
    reportsControllerGetFiatCurrencies(providers: Array<string>, options?: any): AxiosPromise<FiatCurrencyReportList>;
    reportsControllerGetFiatCurrency(fiatCode: string, providers: Array<string>, options?: any): AxiosPromise<FiatCurrencyReportDetails>;
    reportsControllerGetPayment(paymentCode: string, providers: Array<string>, options?: any): AxiosPromise<PaymentReportDetails>;
    reportsControllerGetPayments(providers: Array<string>, options?: any): AxiosPromise<PaymentReportList>;
    reportsControllerGetProvider(providerCode: string, providers: Array<string>, options?: any): AxiosPromise<ProviderReportDetails>;
    reportsControllerGetProviders(providers: Array<string>, options?: any): AxiosPromise<ProviderReportList>;
    reportsControllerGetRegions(providers: Array<string>, options?: any): AxiosPromise<CountryReportList>;
    reportsControllerGetSystem(options?: any): AxiosPromise<SystemReport>;
};
export declare class ReportsApi extends BaseAPI {
    reportsControllerGetCountries(providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<CountryReportList, any>>;
    reportsControllerGetCountry(regionCode: string, providers: Array<string>, countryCode: string, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<CountryReportDetails, any>>;
    reportsControllerGetCryptoCurrencies(providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<CryptoCurrencyReportList, any>>;
    reportsControllerGetCryptoCurrency(cryptoNetwork: string, cryptoAddress: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<CryptoCurrencyReportDetails, any>>;
    reportsControllerGetFiatCurrencies(providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<FiatCurrencyReportList, any>>;
    reportsControllerGetFiatCurrency(fiatCode: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<FiatCurrencyReportDetails, any>>;
    reportsControllerGetPayment(paymentCode: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<PaymentReportDetails, any>>;
    reportsControllerGetPayments(providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<PaymentReportList, any>>;
    reportsControllerGetProvider(providerCode: string, providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<ProviderReportDetails, any>>;
    reportsControllerGetProviders(providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<ProviderReportList, any>>;
    reportsControllerGetRegions(providers: Array<string>, options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<CountryReportList, any>>;
    reportsControllerGetSystem(options?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<SystemReport, any>>;
}
