import { FiatCurrency, CryptoCurrency, Provider, QuoteSortMetadata, QuoteTags, PaymentCustomAction } from './API';
import { ApplePayPaymentInfo, ApplePayPurchaseResult, IApplePaySetup } from './ApplePay';
import { PaymentDetailsIOS } from './PaymentRequest';
import BuyAction from './regions/BuyAction';
export declare enum Environment {
    Development = "development",
    Staging = "staging",
    Production = "production"
}
export declare enum Context {
    Browser = "browser",
    Extension = "extension",
    Mobile = "mobile",
    MobileAndroid = "mobile-android",
    MobileIOS = "mobile-ios",
    Payroll = "payroll"
}
export interface Limits {
    minAmount: number;
    maxAmount: number;
    feeDynamicRate: number;
    feeFixedRate: number;
    quickAmounts?: number[];
}
export interface OnRampSdkConfig {
    verbose?: boolean;
    maxInstanceCount?: number;
    locale?: string;
    activationKeys?: string[];
}
export interface QuoteError {
    error: boolean;
    status: number;
    message: string;
    technicalDetails?: string;
    provider: Provider;
    canRetry: boolean;
    previouslyUsedWeight?: number;
    score?: number;
    amountOut?: number;
}
export interface AllQuotesResponse {
    quotes: (QuoteResponse | QuoteError)[];
    sorted: QuoteSortMetadata[];
    customActions: PaymentCustomAction[];
}
export interface QuoteResponse {
    provider: Provider;
    cryptoTranslation?: string;
    crypto?: CryptoCurrency;
    cryptoId?: string;
    fiat?: FiatCurrency;
    fiatId?: string;
    networkFee?: number;
    providerFee?: number;
    extraFee?: number;
    amountIn?: number;
    amountOut?: number;
    exchangeRate?: number;
    status?: number;
    message?: string;
    error?: boolean;
    paymentMethod?: any;
    receiver?: string;
    amountOutInFiat?: number;
    isNativeApplePay?: boolean;
    score?: number;
    previouslyUsedWeight?: number;
    bestRate?: boolean;
    buy: () => Promise<BuyAction>;
    getApplePayRequestInfo?(setup: IApplePaySetup): ApplePayPaymentInfo;
    purchaseWithApplePay?(paymentDetails: PaymentDetailsIOS): Promise<ApplePayPurchaseResult>;
    isCustomAction?: boolean;
    tags: QuoteTags;
}
export interface AllSellQuotesResponse {
    quotes: (SellQuoteResponse | QuoteError)[];
    sorted: QuoteSortMetadata[];
    customActions: PaymentCustomAction[];
}
export interface SellQuoteResponse {
    provider: Provider;
    crypto?: CryptoCurrency;
    cryptoId?: string;
    fiat?: FiatCurrency;
    fiatId?: string;
    networkFee?: number;
    providerFee?: number;
    extraFee?: number;
    amountIn?: number;
    amountOut?: number;
    exchangeRate?: number;
    status?: number;
    message?: string;
    error?: boolean;
    paymentMethod?: any;
    receiver?: string;
    sell: () => Promise<BuyAction>;
    tags: QuoteTags;
}
export declare enum QuoteRequestType {
    individual = "individual",
    batch = "batch"
}
export declare enum QuoteSortBy {
    none = "0",
    reliability = "1",
    price = "2"
}
