import { Environment, Context, QuoteError, QuoteResponse, OnRampSdkConfig, Limits, SellQuoteResponse, QuoteRequestType, AllQuotesResponse, AllSellQuotesResponse } from './IOnRampSdk';
import { Order, Payment, PaymentType, Country, FiatCurrency, CryptoCurrency, RegionProvider, Provider, OrderStatusEnum, State, ProviderBuyFeatureBrowserEnum, AggregatorNetwork, NetworkDetails } from './API';
import RegionsService from './regions/RegionsService';
import OnRampSdkParameters from './OnRampSdkParameters';
import OrdersService from './OrdersService';
import EnvironmentDetails from './EnvironmentDetails';
import ReportsService from './reports/ReportsService';
import { SdkFunctionIntrospection, SdkParamIntrospection } from './SdkIntrospection';
import ServicesSignatures from './ServicesSignatures';
export declare class OnRampSdk {
    private readonly context;
    private locale;
    private readonly activationKeys;
    static create(connectionUrl: string | Environment | EnvironmentDetails, context: Context, config?: OnRampSdkConfig): OnRampSdk;
    private regionsService;
    private ordersService;
    private reportsService;
    private sdkIntrospection;
    sdkParameters: OnRampSdkParameters;
    private regionsAxios;
    private ordersAxios;
    private reportsAxios;
    private quoteAxios;
    private constructor();
    getActivationKeys(): string[];
    setActivationKeys(keys: string[]): Promise<void>;
    private createAxios;
    regions(): Promise<RegionsService>;
    orders(): Promise<OrdersService>;
    reports(apiKey: string): Promise<ReportsService>;
    private getRegionAxios;
    getQuote(config: any): Promise<import("axios").AxiosResponse<any, any>>;
    getNetworks(): Promise<AggregatorNetwork[]>;
    getNetworkDetails(): Promise<NetworkDetails[]>;
    getVersion(): Promise<{
        [key: string]: string;
    }>;
    setLocale(locale: string): void;
    getSignature(targetClass: Record<string, any>, method: (...args: any[]) => any): SdkFunctionIntrospection;
}
export { Payment, PaymentType, Country, CryptoCurrency, FiatCurrency, QuoteError, QuoteResponse, SellQuoteResponse, AllQuotesResponse, AllSellQuotesResponse, Environment, Context, RegionProvider, Provider, Order, OrdersService, RegionsService, ReportsService, Limits, OrderStatusEnum, State, ProviderBuyFeatureBrowserEnum, SdkFunctionIntrospection, SdkParamIntrospection, QuoteRequestType, ServicesSignatures, };
