"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServicesSignatures = exports.QuoteRequestType = exports.ProviderBuyFeatureBrowserEnum = exports.OrderStatusEnum = exports.ReportsService = exports.RegionsService = exports.OrdersService = exports.Context = exports.Environment = exports.PaymentType = exports.OnRampSdk = void 0;
const IOnRampSdk_1 = require("./IOnRampSdk");
Object.defineProperty(exports, "Environment", { enumerable: true, get: function () { return IOnRampSdk_1.Environment; } });
Object.defineProperty(exports, "Context", { enumerable: true, get: function () { return IOnRampSdk_1.Context; } });
Object.defineProperty(exports, "QuoteRequestType", { enumerable: true, get: function () { return IOnRampSdk_1.QuoteRequestType; } });
const Logger_1 = require("./Logger");
const API_1 = require("./API");
Object.defineProperty(exports, "PaymentType", { enumerable: true, get: function () { return API_1.PaymentType; } });
Object.defineProperty(exports, "OrderStatusEnum", { enumerable: true, get: function () { return API_1.OrderStatusEnum; } });
Object.defineProperty(exports, "ProviderBuyFeatureBrowserEnum", { enumerable: true, get: function () { return API_1.ProviderBuyFeatureBrowserEnum; } });
const axios_1 = __importDefault(require("axios"));
const RegionsService_1 = __importDefault(require("./regions/RegionsService"));
exports.RegionsService = RegionsService_1.default;
const OrdersService_1 = __importDefault(require("./OrdersService"));
exports.OrdersService = OrdersService_1.default;
const Utils_1 = __importDefault(require("./Utils"));
const version_1 = require("./version");
const ReportsService_1 = __importDefault(require("./reports/ReportsService"));
exports.ReportsService = ReportsService_1.default;
const SdkIntrospection_1 = __importDefault(require("./SdkIntrospection"));
const SdkParam_1 = __importDefault(require("./SdkParam"));
const ServicesSignatures_1 = __importDefault(require("./ServicesSignatures"));
exports.ServicesSignatures = ServicesSignatures_1.default;
const logger = new Logger_1.Logger();
class OnRampSdk {
    static create(connectionUrl = 'http://localhost:3000', context, config = {}) {
        const verbose = config.verbose || false;
        const locale = config.locale || 'en-US';
        const sdk = new OnRampSdk(connectionUrl, context, locale, config.activationKeys || []);
        Utils_1.default.checkParameters({ connectionUrl, context });
        logger.setVerbose(verbose);
        return sdk;
    }
    constructor(connectionUrl, context, locale, activationKeys) {
        this.context = context;
        this.locale = locale;
        this.activationKeys = activationKeys;
        this.sdkIntrospection = new SdkIntrospection_1.default();
        const environment = (() => {
            if (typeof connectionUrl === 'string') {
                if ([IOnRampSdk_1.Environment.Staging, 'staging'].includes(connectionUrl)) {
                    return {
                        name: 'Staging',
                        regions: 'https://on-ramp-cache.uat-api.cx.metamask.io',
                        orders: 'https://on-ramp.uat-api.cx.metamask.io',
                        reports: 'https://on-ramp.uat-api.cx.metamask.io',
                    };
                }
                else if ([IOnRampSdk_1.Environment.Production, 'production'].includes(connectionUrl)) {
                    return {
                        name: 'Production',
                        regions: 'https://on-ramp-cache.api.cx.metamask.io',
                        orders: 'https://on-ramp.api.cx.metamask.io',
                        reports: 'https://on-ramp-content.api.cx.metamask.io',
                    };
                }
                else if ([IOnRampSdk_1.Environment.Development, 'development'].includes(connectionUrl)) {
                    return {
                        name: 'Development',
                        regions: 'https://on-ramp.dev-api.cx.metamask.io',
                        orders: 'https://on-ramp.dev-api.cx.metamask.io',
                        reports: 'https://on-ramp.dev-api.cx.metamask.io',
                    };
                }
                else {
                    try {
                        const url = new URL(connectionUrl);
                        const stringUrl = url.toString();
                        return {
                            name: 'Unkown',
                            regions: stringUrl,
                            orders: stringUrl,
                            reports: stringUrl,
                        };
                    }
                    catch (_a) {
                        throw new Error(`Invalid URL: ${connectionUrl}`);
                    }
                }
            }
            else {
                const environmentDetails = connectionUrl;
                if (!environmentDetails.orders && !environmentDetails.regions) {
                    throw new Error(`The specified environment is invalid. Please specify at least on feature URL.`);
                }
                return connectionUrl;
            }
        })();
        this.sdkParameters = {
            context: context,
            environment: environment,
            locale: this.locale,
            activationKeys: activationKeys,
        };
    }
    getActivationKeys() {
        return [...this.sdkParameters.activationKeys];
    }
    async setActivationKeys(keys) {
        var _a, _b;
        this.sdkParameters.activationKeys = keys;
        const serializedKeys = (_a = this.sdkParameters.activationKeys) === null || _a === void 0 ? void 0 : _a.join(',');
        if (this.regionsAxios) {
            this.regionsAxios.defaults.params.keys = serializedKeys;
        }
        if (this.ordersAxios) {
            this.ordersAxios.defaults.params.keys = serializedKeys;
        }
        await ((_b = this.regionsService) === null || _b === void 0 ? void 0 : _b.reset(this));
    }
    createAxios(baseUrl) {
        var _a;
        return axios_1.default.create({
            baseURL: baseUrl,
            headers: {
                'x-csi-context': this.context,
                locale: this.locale,
                'on-ramp-sdk-version': version_1.LIB_VERSION,
            },
            params: {
                sdk: version_1.LIB_VERSION,
                context: this.context,
                keys: (_a = this.sdkParameters.activationKeys) === null || _a === void 0 ? void 0 : _a.join(','),
            },
        });
    }
    async regions() {
        if (!this.regionsService) {
            const newRegionsService = await RegionsService_1.default.create(this.getRegionAxios(), new Logger_1.Logger(), this, this.sdkParameters);
            this.regionsService = newRegionsService;
        }
        else {
            await this.regionsService.reset(this);
        }
        return this.regionsService;
    }
    async orders() {
        if (!this.ordersService) {
            this.ordersAxios = this.createAxios(this.sdkParameters.environment.orders);
            this.ordersService = new OrdersService_1.default(this.ordersAxios, new Logger_1.Logger(), this.sdkParameters);
        }
        return this.ordersService;
    }
    async reports(apiKey) {
        if (!this.reportsService) {
            this.reportsAxios = this.createAxios(this.sdkParameters.environment.reports);
            this.reportsAxios.defaults.headers['X-API-Key'] = apiKey;
            this.reportsService = new ReportsService_1.default(this.reportsAxios, new Logger_1.Logger(), this.sdkParameters, () => this.regions());
        }
        return this.reportsService;
    }
    getRegionAxios() {
        if (!this.regionsAxios) {
            this.regionsAxios = this.createAxios(this.sdkParameters.environment.regions);
        }
        return this.regionsAxios;
    }
    getQuote(config) {
        if (!this.quoteAxios) {
            this.quoteAxios = this.createAxios('');
        }
        return this.quoteAxios(config);
    }
    async getNetworks() {
        const result = await Utils_1.default.try(async () => (await this.getRegionAxios().get('/regions/networks'))
            .data);
        return result === null || result === void 0 ? void 0 : result.networks;
    }
    async getNetworkDetails() {
        const result = await Utils_1.default.try(async () => (await this.getRegionAxios().get('/regions/network-details'))
            .data);
        return result;
    }
    async getVersion() {
        const axios = this.createAxios(null);
        const regionsVersions = (await axios.get(this.sdkParameters.environment.regions)).data.version;
        const ordersVersions = (await axios.get(this.sdkParameters.environment.orders)).data.version;
        const environmentName = this.sdkParameters.environment.name;
        return {
            sdk: version_1.LIB_VERSION,
            api: ordersVersions,
            cache: regionsVersions,
            environment: environmentName,
        };
    }
    setLocale(locale) {
        if (this.ordersAxios) {
            this.ordersAxios.defaults.headers['locale'] = locale;
        }
        if (this.regionsAxios) {
            this.regionsAxios.defaults.headers['locale'] = locale;
        }
    }
    getSignature(targetClass, method) {
        return this.sdkIntrospection.getSignature(targetClass, method);
    }
}
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Array]),
    __metadata("design:returntype", Promise)
], OnRampSdk.prototype, "setActivationKeys", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], OnRampSdk.prototype, "reports", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], OnRampSdk.prototype, "setLocale", null);
exports.OnRampSdk = OnRampSdk;
