"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _OrdersService_instances, _OrdersService_getOrderWithParams;
Object.defineProperty(exports, "__esModule", { value: true });
const SdkParam_1 = __importDefault(require("./SdkParam"));
const Utils_1 = __importDefault(require("./Utils"));
const ApplePay_1 = require("./ApplePay");
class OrdersService {
    constructor(axios, logger, sdkParameters) {
        this.axios = axios;
        this.logger = logger;
        this.sdkParameters = sdkParameters;
        _OrdersService_instances.add(this);
        this.providerCache = new Map();
    }
    async getOrderIdFromCallback(providerId, redirectUrl) {
        var _a;
        Utils_1.default.checkParameters({ providerId, redirectUrl });
        try {
            return (_a = (await this.axios.get(`${providerId}/callback?url=${encodeURIComponent(redirectUrl)}`)).data) === null || _a === void 0 ? void 0 : _a.id;
        }
        catch (_b) {
            return undefined;
        }
    }
    async getOrderFromCallback(providerId, redirectUrl, walletAddress) {
        Utils_1.default.checkParameters({ providerId, redirectUrl, walletAddress });
        const orderId = await this.getOrderIdFromCallback(providerId, redirectUrl);
        if (!orderId) {
            return null;
        }
        const order = await __classPrivateFieldGet(this, _OrdersService_instances, "m", _OrdersService_getOrderWithParams).call(this, orderId, {
            wallet: walletAddress,
            fromRedirection: true,
        });
        return order;
    }
    async getSellOrderFromCallback(providerId, redirectUrl, walletAddress) {
        var _a;
        Utils_1.default.checkParameters({ providerId, redirectUrl, walletAddress });
        const orderId = (_a = (await this.axios.get(`${providerId}/sell-callback?url=${encodeURIComponent(redirectUrl)}`)).data) === null || _a === void 0 ? void 0 : _a.id;
        const order = await __classPrivateFieldGet(this, _OrdersService_instances, "m", _OrdersService_getOrderWithParams).call(this, orderId, {
            wallet: walletAddress,
            fromRedirection: true,
        });
        return order;
    }
    async getOrder(orderId, walletAddress) {
        const order = await __classPrivateFieldGet(this, _OrdersService_instances, "m", _OrdersService_getOrderWithParams).call(this, orderId, {
            wallet: walletAddress,
        });
        return order;
    }
    async getSellOrder(orderId, walletAddress) {
        const order = await __classPrivateFieldGet(this, _OrdersService_instances, "m", _OrdersService_getOrderWithParams).call(this, orderId, {
            wallet: walletAddress,
        });
        return order;
    }
    async submitApplePayOrder(dest, providerId, payload) {
        const response = await Utils_1.default.try(async () => await this.axios.post(`${providerId}/order/apple-pay`, payload, {
            validateStatus: () => true,
            headers: {
                Accept: 'application/json',
                'Content-Type': 'application/json',
            },
            timeout: 25000,
        }));
        console.log(`Got response from ${providerId}/order/apple-pay`);
        if (response.status >= 200 && response.status < 300) {
            const orderId = response.data.id;
            const order = await this.getOrder(`${providerId}/orders/${orderId}`, dest);
            if (response.data.authenticationUrl) {
                return {
                    status: ApplePay_1.ApplePayPurchaseStatus.PENDING,
                    authenticationUrl: response.data.authenticationUrl,
                    order: order,
                };
            }
            else {
                return {
                    status: ApplePay_1.ApplePayPurchaseStatus.SUCCESS,
                    order: order,
                };
            }
        }
        else {
            return {
                status: ApplePay_1.ApplePayPurchaseStatus.FAILURE,
                error: response.data,
            };
        }
    }
    async getProviders() {
        const response = await Utils_1.default.try(async () => await this.axios.get('/providers'));
        response.data.forEach((provider) => {
            this.providerCache.set(provider.id, provider);
        });
    }
    async getProvider(providerId) {
        if (!this.providerCache.get(providerId)) {
            await this.getProviders();
        }
        return this.providerCache.get(providerId);
    }
    async getRecurringOrders(orderId, walletAddress, start, end) {
        const url = `${orderId}/recurring?wallet=${encodeURIComponent(walletAddress)}&start=${start === null || start === void 0 ? void 0 : start.toISOString()}&end=${end === null || end === void 0 ? void 0 : end.toISOString()}`;
        const orders = await this.getRecurringOrdersFromUrl(url);
        return orders;
    }
    async getRecurringOrdersFromUrl(url) {
        var _a;
        const orders = (await this.axios.get(url)).data;
        for (const order of orders.orders) {
            Utils_1.default.setProviderAbsoluteUrls(this.sdkParameters.environment.regions, order.provider);
        }
        const next = ((_a = orders === null || orders === void 0 ? void 0 : orders.links) === null || _a === void 0 ? void 0 : _a.next)
            ? () => this.getRecurringOrdersFromUrl(orders.links.next)
            : null;
        return {
            orders: orders.orders,
            next: next,
        };
    }
    addRedirectionListener(callback) {
        window.addEventListener('message', async (event) => {
            var _a;
            if (event.origin !== Utils_1.default.trimUrl(this.sdkParameters.environment.regions)) {
                return;
            }
            if (((_a = event === null || event === void 0 ? void 0 : event.data) === null || _a === void 0 ? void 0 : _a.type) !== 'redirection') {
                return;
            }
            if (event.data && typeof event.data.orderId === 'string') {
                await callback(event.data.orderId);
            }
            else {
                await callback(null);
            }
        }, false);
    }
}
_OrdersService_instances = new WeakSet(), _OrdersService_getOrderWithParams = async function _OrdersService_getOrderWithParams(orderId, params) {
    try {
        const order = (await this.axios.get(orderId, { params })).data;
        Utils_1.default.setProviderAbsoluteUrls(this.sdkParameters.environment.regions, order.provider);
        return order;
    }
    catch (err) {
        throw new Error(`An unexpected error occurred while retrieving order information.${(err === null || err === void 0 ? void 0 : err.message) ? ` ${err.message}` : ''}`);
    }
};
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], OrdersService.prototype, "getOrderIdFromCallback", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, String]),
    __metadata("design:returntype", Promise)
], OrdersService.prototype, "getOrderFromCallback", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, String]),
    __metadata("design:returntype", Promise)
], OrdersService.prototype, "getSellOrderFromCallback", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], OrdersService.prototype, "getOrder", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], OrdersService.prototype, "getSellOrder", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], OrdersService.prototype, "getProvider", null);
exports.default = OrdersService;
