export interface PaymentMethodData {
    supportedMethods: Array<string>;
    data: any;
}
export interface PaymentCurrencyAmount {
    currency: string;
    value: string;
}
export interface PaymentDetailsBase {
    displayItems: Array<PaymentItem>;
    shippingOptions: Array<PaymentShippingOption>;
    modifiers: Array<PaymentDetailsModifier>;
}
export interface PaymentDetailsInit extends PaymentDetailsBase {
    id?: string;
    total: PaymentItem;
}
export interface PaymentDetailsUpdate extends PaymentDetailsBase {
    error: string;
    total: PaymentItem;
}
export type PaymentDetailsModifier = {
    supportedMethods: Array<string>;
    total: PaymentItem;
    additionalDisplayItems: Array<PaymentItem>;
    data: any;
};
export type PaymentShippingType = 'shipping' | 'delivery' | 'pickup';
export interface PaymentOptions {
    requestPayerName: boolean;
    requestPayerEmail: boolean;
    requestPayerPhone: boolean;
    requestShipping: boolean;
    requestBilling: boolean;
    shippingType: PaymentShippingType;
}
export interface PaymentItem {
    label: string;
    amount: PaymentCurrencyAmount;
    pending: boolean;
}
export interface PaymentAddress {
    recipient: null | string;
    organization: null | string;
    addressLine: null | string;
    city: string;
    region: string;
    country: string;
    postalCode: string;
    phone: null | string;
    languageCode: null | string;
    sortingCode: null | string;
    dependentLocality: null | string;
}
export interface PaymentShippingOption {
    id: string;
    label: string;
    amount: PaymentCurrencyAmount;
    selected: boolean;
}
export type PaymentComplete = 'fail' | 'success' | 'unknown';
export interface PaymentDetailsIOS {
    paymentData: any;
    billingContact?: any;
    shippingContact?: any;
    paymentToken?: string;
    transactionIdentifier: string;
    paymentMethod: any;
}
export interface PaymentDetailsIOSRaw {
    paymentData: string;
    billingContact?: string;
    shippingContact?: string;
    paymentToken?: string;
    transactionIdentifier: string;
    paymentMethod: any;
}
