"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Utils {
    static checkParameters(parameters) {
        for (const [parameterName, parameterValue] of Object.entries(parameters)) {
            if (parameterValue === undefined) {
                throw new Error(`Parameter "${parameterName}" is missing.`);
            }
        }
    }
    static async downloadAsMap(axios, url, resultSelector = (obj) => obj, idSelector = (obj) => obj.id) {
        const deserializedResult = (await axios.get(url)).data;
        const selectedResult = resultSelector(deserializedResult);
        const map = new Map(selectedResult.map((r) => [idSelector(r), r]));
        return map;
    }
    static stringify(o, space) {
        let cache = [];
        const retVal = JSON.stringify(o, (key, value) => typeof value === 'object' && value !== null
            ? cache.includes(value)
                ? undefined
                : cache.push(value) && value
            : value, space);
        cache = null;
        return retVal;
    }
    static setProviderAbsoluteUrls(baseUrl, provider) {
        var _a, _b;
        if ((_a = provider.logos) === null || _a === void 0 ? void 0 : _a.dark) {
            provider.logos.dark = new URL(provider.logos.dark, baseUrl).href;
        }
        if ((_b = provider.logos) === null || _b === void 0 ? void 0 : _b.light) {
            provider.logos.light = new URL(provider.logos.light, baseUrl).href;
        }
        return provider;
    }
    static setPaymentAbsoluteUrls(baseUrl, payment) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p;
        try {
            if ((_a = payment.logo) === null || _a === void 0 ? void 0 : _a.dark) {
                payment.logo.dark.forEach((logo, index) => {
                    payment.logo.dark[index] = new URL(logo, baseUrl).href;
                });
            }
            if ((_b = payment.logo) === null || _b === void 0 ? void 0 : _b.light) {
                payment.logo.light.forEach((logo, index) => {
                    payment.logo.light[index] = new URL(logo, baseUrl).href;
                });
            }
            const setCustomActionUrl = (theme) => {
                var _a;
                (_a = theme === null || theme === void 0 ? void 0 : theme.value) === null || _a === void 0 ? void 0 : _a.map((item) => {
                    var _a, _b;
                    if ((_b = (_a = item === null || item === void 0 ? void 0 : item.image) === null || _a === void 0 ? void 0 : _a.url) === null || _b === void 0 ? void 0 : _b.startsWith('/')) {
                        item.image.url = new URL(item.image.url, baseUrl).href;
                    }
                });
            };
            setCustomActionUrl((_d = (_c = payment === null || payment === void 0 ? void 0 : payment.customAction) === null || _c === void 0 ? void 0 : _c.button) === null || _d === void 0 ? void 0 : _d.light);
            setCustomActionUrl((_f = (_e = payment === null || payment === void 0 ? void 0 : payment.customAction) === null || _e === void 0 ? void 0 : _e.button) === null || _f === void 0 ? void 0 : _f.dark);
            setCustomActionUrl((_h = (_g = payment === null || payment === void 0 ? void 0 : payment.customAction) === null || _g === void 0 ? void 0 : _g.sellButton) === null || _h === void 0 ? void 0 : _h.light);
            setCustomActionUrl((_k = (_j = payment === null || payment === void 0 ? void 0 : payment.customAction) === null || _j === void 0 ? void 0 : _j.sellButton) === null || _k === void 0 ? void 0 : _k.dark);
            setCustomActionUrl((_m = (_l = payment === null || payment === void 0 ? void 0 : payment.customAction) === null || _l === void 0 ? void 0 : _l.buyButton) === null || _m === void 0 ? void 0 : _m.light);
            setCustomActionUrl((_p = (_o = payment === null || payment === void 0 ? void 0 : payment.customAction) === null || _o === void 0 ? void 0 : _o.buyButton) === null || _p === void 0 ? void 0 : _p.dark);
            return payment;
        }
        catch (_q) { }
    }
    static async try(action, isSuccess = () => true, maxTrials = 3) {
        let remainingTrials = maxTrials;
        let success = false;
        let result;
        while (remainingTrials >= 1 && !success) {
            remainingTrials--;
            try {
                result = await action();
                success = isSuccess(result);
            }
            catch (err) {
                if (remainingTrials <= 0) {
                    throw err;
                }
            }
        }
        return result;
    }
    static trimUrl(url) {
        return url.endsWith('/') ? url.substring(0, url.length - 1) : url;
    }
}
exports.default = Utils;
