"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const GenericProviderSDK_1 = require("./GenericProviderSDK");
const API_1 = require("../../API");
const RegionsService_1 = require("../../regions/RegionsService");
const createMockProvider = () => ({
    provider: {
        id: 'test-provider',
        name: 'Test Provider',
        logos: {
            light: 'light-logo-url',
            dark: 'dark-logo-url',
            height: 100,
            width: 100,
        },
        description: '',
        hqAddress: '',
        links: [],
        environmentType: 'STAGING',
        features: {
            buy: {
                enabled: true,
                browser: API_1.ProviderBuyFeatureBrowserEnum.InAppOsBrowser,
                redirection: API_1.ProviderBuyFeatureRedirectionEnum.HttpRedirection,
                userAgent: '',
                padCustomOrderId: false,
                orderCustomIdRequired: false,
                orderCustomId: '',
                orderCustomIdPrefixes: [],
                orderCustomIdExpiration: 0,
                supportedByBackend: true,
                orderCustomIdSeparator: '',
            },
            recurringBuy: {
                enabled: false,
            },
            quotes: {
                enabled: true,
                supportedByBackend: true,
            },
        },
    },
    supportedFiatCurrencies: [
        {
            id: 'USD',
            translation: 'USD',
            limits: {
                'credit-card': {
                    minAmount: 10,
                    maxAmount: 1000,
                    feeDynamicRate: 0,
                    feeFixedRate: 0,
                },
            },
            excludedPaymentMethods: [],
        },
    ],
    supportedCryptoCurrencies: [
        {
            id: 'BTC',
            translation: 'BTC',
            specificNetworkId: '',
            excludedFiat: [],
            excludedFiatAndPaymentMethods: [],
            limits: {
                minAmount: 5,
                maxAmount: 2000,
                feeDynamicRate: 0,
                feeFixedRate: 0,
                payments: [
                    {
                        payment: 'credit-card',
                        minAmount: 15,
                        maxAmount: 500,
                        feeDynamicRate: 0,
                        feeFixedRate: 0,
                    },
                ],
            },
        },
    ],
    data: {},
    supportedPaymentMethods: [],
    quote: '',
    sellQuote: '',
    quoteTransformation: undefined,
    sellQuoteTransformation: undefined,
});
const createMockQuoteOrQuery = (overrides = {}) => (Object.assign({ url: '', method: '', headers: {}, provider: 'mockProviderWithTransform', providerInfo: {
        id: 'mockProviderWithTransform',
        name: 'Mock Provider',
        logos: {
            light: 'light-logo-url',
            dark: 'dark-logo-url',
            height: 100,
            width: 100,
        },
        description: '',
        hqAddress: '',
        links: [],
        environmentType: 'STAGING',
        features: {
            buy: {
                enabled: true,
                browser: API_1.ProviderBuyFeatureBrowserEnum.InAppOsBrowser,
                redirection: API_1.ProviderBuyFeatureRedirectionEnum.HttpRedirection,
                userAgent: '',
                padCustomOrderId: false,
                orderCustomIdRequired: false,
                orderCustomId: '',
                orderCustomIdPrefixes: [],
                orderCustomIdExpiration: 0,
                supportedByBackend: true,
                orderCustomIdSeparator: '',
            },
            recurringBuy: {
                enabled: false,
            },
            quotes: {
                enabled: true,
                supportedByBackend: true,
            },
        },
    }, providerQuote: null, nativeApplePay: { supported: false, merchantId: '' }, metadata: {
        tags: {
            isBestRate: true,
            isMostReliable: false,
        },
        reliability: 1,
    }, quote: {
        cryptoId: 'BTC',
        fiatId: 'USD',
        status: 1,
        message: '',
        error: null,
        bestRate: true,
        isCustomAction: false,
        extraFee: 0,
        crypto: {
            id: 'BTC',
            name: 'Bitcoin',
            decimals: 8,
            symbol: 'BTC',
            idv2: 'BTC',
            legacyId: 'BTC',
            network: {
                active: true,
                chainName: 'Bitcoin',
                shortName: 'BTC',
                chainId: '1',
            },
            logo: '',
            address: '',
            limits: [],
            sellEnabled: true,
            assetId: '',
        },
        fiat: {
            id: 'USD',
            name: 'US Dollar',
            symbol: '$',
            decimals: 2,
            denomSymbol: 'USD',
        },
        networkFee: 1,
        providerFee: 2,
        amountIn: 100,
        amountOut: 0.5,
        paymentMethod: { type: 'credit-card' },
        receiver: 'wallet123',
    } }, overrides));
describe('GenericProviderSDK', () => {
    let sdk;
    let mockOnRampSdk;
    let mockLogger;
    let mockProvider;
    beforeEach(() => {
        mockLogger = {
            log: jest.fn(),
        };
        mockOnRampSdk = {
            sdkParameters: {
                environment: {
                    orders: 'https://api.test.com/',
                },
            },
            getQuote: jest.fn(),
            regions: jest.fn(),
            orders: jest.fn(),
        };
        mockProvider = createMockProvider();
        sdk = new GenericProviderSDK_1.GenericProviderSDK(mockOnRampSdk, 'test-provider', mockLogger);
    });
    describe('getId', () => {
        it('should return provider id', () => {
            expect(sdk.getId()).toBe('test-provider');
        });
    });
    describe('getLimit', () => {
        it('should return combined limits from fiat and crypto', async () => {
            const result = await sdk.getLimit(mockProvider, 'USD', 'BTC', [
                'credit-card',
            ]);
            expect(result.minAmount).toBe(15);
            expect(result.maxAmount).toBe(500);
        });
        it('should handle missing fiat limits', async () => {
            const modifiedProvider = Object.assign(Object.assign({}, mockProvider), { supportedFiatCurrencies: [
                    {
                        id: 'USD',
                        translation: 'USD',
                        limits: {},
                        excludedPaymentMethods: [],
                    },
                ] });
            const result = await sdk.getLimit(modifiedProvider, 'USD', 'BTC', [
                'credit-card',
            ]);
            expect(result.minAmount).toBe(15);
            expect(result.maxAmount).toBe(500);
        });
        it('should handle missing crypto limits', async () => {
            const modifiedProvider = Object.assign(Object.assign({}, mockProvider), { supportedCryptoCurrencies: [
                    {
                        id: 'BTC',
                        translation: 'BTC',
                        limits: {
                            minAmount: 0,
                            maxAmount: 0,
                            feeFixedRate: 0,
                            feeDynamicRate: 0,
                            payments: [],
                        },
                        excludedPaymentMethods: [],
                        specificNetworkId: '',
                        excludedFiat: [],
                        excludedFiatAndPaymentMethods: [],
                    },
                ] });
            const result = await sdk.getLimit(modifiedProvider, 'USD', 'BTC', [
                'credit-card',
            ]);
            expect(result.minAmount).toBe(10);
            expect(result.maxAmount).toBe(1000);
        });
    });
    describe('getSellLimit', () => {
        it('should return sell limits for crypto', async () => {
            const result = await sdk.getSellLimit(mockProvider, 'USD', 'BTC', [
                'credit-card',
            ]);
            expect(result).toEqual({
                minAmount: -Infinity,
                maxAmount: Infinity,
                feeFixedRate: 0,
                feeDynamicRate: 0,
                quickAmounts: [],
            });
        });
    });
    describe('formatQuote', () => {
        it('should format buy quote correctly', async () => {
            const mockProvider = createMockProvider();
            const quoteOrQuery = createMockQuoteOrQuery();
            const result = await sdk.formatQuote(quoteOrQuery, mockProvider.provider, 'region1', 'credit-card', 'BTC', 'USD', 100, RegionsService_1.ProviderAction.buy, 'wallet123');
            expect(result).toMatchObject({
                provider: mockProvider.provider,
                crypto: quoteOrQuery.quote.crypto,
                cryptoId: 'BTC',
                fiat: quoteOrQuery.quote.fiat,
                fiatId: 'USD',
                networkFee: 1,
                providerFee: 2,
                extraFee: 0,
                amountIn: 100,
                amountOut: 0.5,
                tags: {
                    isBestRate: true,
                    isMostReliable: false,
                },
            });
        });
        it('should format sell quote correctly', async () => {
            const quoteOrQuery = createMockQuoteOrQuery();
            const result = await sdk.formatQuote(quoteOrQuery, mockProvider.provider, 'region1', 'bank-transfer', 'BTC', 'USD', 0.5, RegionsService_1.ProviderAction.sell, 'account123');
            expect(result).toMatchObject({
                provider: mockProvider.provider,
                crypto: quoteOrQuery.quote.crypto,
                cryptoId: 'BTC',
                fiat: quoteOrQuery.quote.fiat,
                fiatId: 'USD',
                networkFee: 1,
                providerFee: 2,
                extraFee: 0,
                amountIn: 100,
                amountOut: 0.5,
                tags: {
                    isBestRate: true,
                    isMostReliable: false,
                },
            });
        });
        it('should handle missing metadata and tags', async () => {
            const quoteOrQuery = createMockQuoteOrQuery();
            const result = await sdk.formatQuote(quoteOrQuery, mockProvider.provider, 'region1', 'credit-card', 'BTC', 'USD', 100, RegionsService_1.ProviderAction.buy, 'wallet123');
            expect(result).toMatchObject({
                provider: mockProvider.provider,
                crypto: quoteOrQuery.quote.crypto,
                cryptoId: 'BTC',
                fiat: quoteOrQuery.quote.fiat,
                fiatId: 'USD',
                networkFee: 1,
                providerFee: 2,
                amountIn: 100,
                amountOut: 0.5,
                tags: {
                    isBestRate: true,
                    isMostReliable: false,
                },
            });
        });
        it('should handle quote transformation if provided', async () => {
            const mockProviderWithTransform = Object.assign(Object.assign({}, mockProvider), { quoteTransformation: {
                    amountIn: (amount) => amount * 2,
                    amountOut: (amount) => amount / 2,
                } });
            const quoteOrQuery = createMockQuoteOrQuery();
            const result = await sdk.formatQuote(quoteOrQuery, mockProviderWithTransform.provider, 'region1', 'credit-card', 'BTC', 'USD', 100, RegionsService_1.ProviderAction.buy, 'wallet123');
            if ('error' in result) {
                fail('Expected QuoteResponse but got QuoteError');
            }
            else {
                expect(result.amountIn).toBe(100);
                expect(result.amountOut).toBe(0.5);
            }
        });
        it('should handle quote with native Apple Pay', async () => {
            const quoteOrQuery = createMockQuoteOrQuery({
                nativeApplePay: { supported: true, merchantId: 'merchant123' },
            });
            const result = (await sdk.formatQuote(quoteOrQuery, mockProvider.provider, 'region1', 'credit-card', 'BTC', 'USD', 100, RegionsService_1.ProviderAction.buy, 'wallet123'));
            if ('error' in result) {
                fail('Expected QuoteResponse but got QuoteError');
            }
            expect(result.isNativeApplePay).toBe(true);
        });
        it('should handle quote with custom action', async () => {
            const quoteOrQuery = createMockQuoteOrQuery({
                quote: Object.assign(Object.assign({}, createMockQuoteOrQuery().quote), { isCustomAction: true }),
            });
            const result = (await sdk.formatQuote(quoteOrQuery, mockProvider.provider, 'region1', 'credit-card', 'BTC', 'USD', 100, RegionsService_1.ProviderAction.buy, 'wallet123'));
            if ('error' in result) {
                fail('Expected QuoteResponse but got QuoteError');
            }
            expect(result.isCustomAction).toBe(true);
        });
        it.skip('should handle quote error', async () => {
            const quoteError = {
                error: true,
                status: 400,
                message: 'Test error',
                provider: mockProvider.provider,
                canRetry: false,
            };
            const result = (await sdk.formatQuote(quoteError, mockProvider.provider, 'region1', 'credit-card', 'BTC', 'USD', 100, RegionsService_1.ProviderAction.buy, 'wallet123'));
            expect(result).toEqual(quoteError);
        });
    });
    describe('getQuote', () => {
        it.skip('should handle remote quote error', async () => {
            mockOnRampSdk.getQuote.mockResolvedValue({
                status: 400,
                data: {
                    error: {
                        statusCode: 400,
                        message: 'Bad Request',
                    },
                },
                statusText: 'Bad Request',
                headers: {},
                config: {},
            });
            const result = await sdk.getQuote(mockProvider, 'quote-uri', 'region1', 'credit-card', 'BTC', 'USD', 100, 'wallet123');
            expect(result).toHaveProperty('error', true);
            expect(result).toHaveProperty('message', 'Bad Request');
        });
        it('should handle empty quote response', async () => {
            mockOnRampSdk.getQuote.mockResolvedValue({
                status: 200,
                data: {},
                statusText: 'OK',
                headers: {},
                config: {},
            });
            const result = await sdk.getQuote(mockProvider, 'quote-uri', 'region1', 'credit-card', 'BTC', 'USD', 100, 'wallet123');
            expect(result).toHaveProperty('error', true);
            expect(result).toHaveProperty('message', 'Unable to get quote from test-provider');
        });
    });
    describe('getSellQuote', () => {
        it('should handle successful sell quote', async () => {
            mockOnRampSdk.getQuote.mockResolvedValue({
                status: 200,
                data: createMockQuoteOrQuery(),
                statusText: 'OK',
                headers: {},
                config: {},
            });
            const result = await sdk.getSellQuote(mockProvider, 'quote-uri', 'region1', 'bank-transfer', 'BTC', 'USD', 0.5, 'account123');
            if ('error' in result) {
                fail('Expected SellQuoteResponse but got QuoteError');
            }
            expect(result.amountIn).toBe(100);
            expect(result.amountOut).toBe(0.5);
        });
        it.skip('should handle sell quote error', async () => {
            mockOnRampSdk.getQuote.mockResolvedValue({
                status: 400,
                data: {
                    error: {
                        statusCode: 400,
                        message: 'Invalid sell amount',
                    },
                },
                statusText: 'Bad Request',
                headers: {},
                config: {},
            });
            const result = await sdk.getSellQuote(mockProvider, 'quote-uri', 'region1', 'bank-transfer', 'BTC', 'USD', 0.5, 'account123');
            expect(result).toHaveProperty('error', true);
            expect(result).toHaveProperty('message', 'Invalid sell amount');
        });
    });
});
