"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const GenericProviderSDK_1 = require("./Generic/GenericProviderSDK");
const ProviderList_1 = __importDefault(require("./ProviderList"));
describe('ProviderList', () => {
    let providerList;
    let mockOnRampSdk;
    let mockLogger;
    let mockProvider;
    beforeEach(() => {
        mockOnRampSdk = {};
        mockLogger = {};
        mockProvider = {
            getId: jest.fn().mockReturnValue('test-provider-id'),
        };
        providerList = new ProviderList_1.default(mockOnRampSdk, mockLogger);
    });
    describe('register', () => {
        it('should register a provider correctly', () => {
            providerList.register(mockProvider);
            const provider = providerList.get('test-provider-id');
            expect(provider).toBe(mockProvider);
        });
    });
    describe('get', () => {
        it('should return a registered provider', () => {
            providerList.register(mockProvider);
            const provider = providerList.get('test-provider-id');
            expect(provider).toBe(mockProvider);
        });
        it('should return a GenericProviderSDK when provider is not registered', () => {
            const nonExistentProviderId = 'non-existent-provider';
            const provider = providerList.get(nonExistentProviderId);
            expect(provider).toBeInstanceOf(GenericProviderSDK_1.GenericProviderSDK);
        });
    });
});
