"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CountryCache = void 0;
const Utils_1 = __importDefault(require("../Utils"));
class CountryCache {
    constructor(countryId, cachedPayments, cachedCryptoCurrencies, cachedFiatCurrencies, cachedParameters, expirationDate, limits) {
        this.countryId = countryId;
        this.cachedPayments = cachedPayments;
        this.cachedCryptoCurrencies = cachedCryptoCurrencies;
        this.cachedFiatCurrencies = cachedFiatCurrencies;
        this.cachedParameters = cachedParameters;
        this.expirationDate = expirationDate;
        this.limits = limits;
    }
    static async Create(logger, axios, baseUrl, action, countryId, paymentIds, fiatId, cryptoId, abortController) {
        logger.log(`Querying URL ${countryId}`);
        const axiosResponse = await axios.get(countryId + '/light', {
            params: {
                payment: paymentIds ? paymentIds.join(',') : [],
                fiat: fiatId,
                crypto: cryptoId,
                action: action,
                multiplePayments: true,
            },
            signal: abortController === null || abortController === void 0 ? void 0 : abortController.signal,
        });
        const expirationDate = CountryCache.getCacheExpirationDate(axiosResponse);
        const cacheInfo = axiosResponse.data;
        const payments = cacheInfo.payments.map((p) => CountryCache.setAbsolutePaymentUrls(baseUrl, p));
        const crypto = new Map(cacheInfo.cryptoCurrencies.map((c) => [c.id, c]));
        const fiat = new Map(cacheInfo.fiatCurrencies.map((f) => [f.id, f]));
        const parameters = cacheInfo.parameters;
        return new CountryCache(countryId, payments, crypto, fiat, parameters, expirationDate, cacheInfo.limits);
    }
    static getCacheExpirationDate(axiosReponse) {
        try {
            const cacheControlHeader = axiosReponse.headers['cache-control'];
            if (!cacheControlHeader) {
                return new Date();
            }
            const values = cacheControlHeader
                .split(',')
                .map((i) => i.trim().split('='));
            const maxAge = parseInt(values.find((i) => i[0] === 'max-age')[1]);
            const expiration = new Date(new Date().getTime() + maxAge * 1000);
            return expiration;
        }
        catch (_a) {
            return new Date();
        }
    }
    static setAbsoluteUrls(baseUrl, provider) {
        Utils_1.default.setProviderAbsoluteUrls(baseUrl, provider.provider);
        return provider;
    }
    static setAbsolutePaymentUrls(baseUrl, payment) {
        Utils_1.default.setPaymentAbsoluteUrls(baseUrl, payment);
        return payment;
    }
}
exports.CountryCache = CountryCache;
