import { Logger } from '../Logger';
import { OnRampSdk } from '../OnRampSdk';
import OnRampSdkParameters from '../OnRampSdkParameters';
import { Country, CryptoCurrency, FiatCurrency, Payment, Provider, RegionCacheParameters, NetworkDetails, BatchQuoteOrQuery } from '../API';
import { Limits, AllQuotesResponse, AllSellQuotesResponse } from '../IOnRampSdk';
import BuyAction from './BuyAction';
export declare enum ProviderAction {
    unknown = "",
    buy = "buy",
    recurringBuy = "recurring-buy",
    sell = "sell"
}
export default class RegionsService {
    private readonly axios;
    private readonly logger;
    private readonly sdkParameters;
    private static instanceCount;
    private disabledLimit;
    static create(axios: any, logger: Logger, sdk: OnRampSdk, sdkParameters: OnRampSdkParameters): Promise<RegionsService>;
    private cachedCountries;
    private countryCache;
    private providers;
    private constructor();
    reset(sdk: any): Promise<void>;
    private downloadCachedCountries;
    private init;
    private buildProviders;
    private getCacheId;
    private getCountryCache;
    getCountries(): Promise<Country[]>;
    getSellCountries(): Promise<Country[]>;
    getPaymentMethods(regionId: string, abortController?: AbortController): Promise<Payment[]>;
    getPaymentMethodsForCrypto(regionId: string, crypto: string, fiat: string, abortController?: AbortController): Promise<Payment[]>;
    getSellPaymentMethodsForCrypto(regionId: string, crypto: string, fiat: string, abortController?: AbortController): Promise<Payment[]>;
    getSellPaymentMethods(regionId: string, abortController?: AbortController): Promise<Payment[]>;
    getPaymentMethod(regionId: string, id: string, action: ProviderAction): Promise<Payment>;
    getDefaultFiatCurrency(regionId: string, paymentMethods: string[]): Promise<FiatCurrency>;
    getDefaultFiatCurrencySync(countries: Country[], fiats: FiatCurrency[], regionId: string, paymentMethods: string[]): FiatCurrency;
    getDefaultSellFiatCurrency(regionId: string, paymentMethods: string[]): Promise<FiatCurrency>;
    getDefaultSellFiatCurrencySync(countries: Country[], fiats: FiatCurrency[], regionId: string, paymentMethods: string[]): FiatCurrency;
    getCryptoCurrencies(regionId: string, paymentMethodIds: string[], fiatCurrencyId?: string, abortController?: AbortController): Promise<CryptoCurrency[]>;
    getNetworkDetails(): Promise<NetworkDetails[]>;
    getSellCryptoCurrencies(regionId: string, paymentMethodIds: string[], fiatCurrencyId?: string, abortController?: AbortController): Promise<CryptoCurrency[]>;
    private getCryptoCurrenciesSync;
    private getSellCryptoCurrenciesSync;
    getCryptoCurrency(regionId: string, cryptoId: string): Promise<CryptoCurrency>;
    getFiatCurrencies(regionId: string, paymentMethodIds: string[], abortController?: AbortController): Promise<FiatCurrency[]>;
    getSellFiatCurrencies(regionId: string, paymentMethodIds: string[], abortController?: AbortController): Promise<FiatCurrency[]>;
    getFiatCurrency(regionId: string, fiatId: string): Promise<FiatCurrency>;
    private getProvidersWithoutAmountSync;
    getLimits(regionId: string, paymentMethods: string[], crypto: string, fiat: string, abortController?: AbortController): Promise<Limits>;
    getSellLimits(regionId: string, paymentMethods: string[], crypto: string, fiat: string): Promise<Limits>;
    getQuotes(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, receiver?: string, abortController?: AbortController): Promise<AllQuotesResponse>;
    getQuotesWithoutCache(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, receiver?: string, action?: ProviderAction, abortController?: AbortController): Promise<AllQuotesResponse>;
    makeQuoteCall(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, receiver?: string, action?: ProviderAction, abortController?: AbortController): Promise<AllQuotesResponse | AllSellQuotesResponse>;
    getAllQuotesFromApi(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, receiver?: string, action?: ProviderAction, abortController?: AbortController): Promise<BatchQuoteOrQuery>;
    getAllQuotesFromApiWithoutCache(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, receiver?: string, action?: ProviderAction, abortController?: AbortController): Promise<BatchQuoteOrQuery>;
    private getExchangeRateFromAPI;
    private getRankingDataFromApi;
    getSellCustomActions(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, abortController?: AbortController): Promise<Payment[]>;
    getCustomActions(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, abortController?: AbortController): Promise<Payment[]>;
    getSellQuotes(regionId: string, paymentMethods: string[], crypto: string, fiat: string, amount: number | string, receiver?: string, abortController?: AbortController): Promise<AllSellQuotesResponse>;
    private getQuickAmounts;
    private standardizeQuote;
    private standardizeSellQuote;
    private getExchangeRate;
    private getSellExchangeRate;
    getParameters(regionId: string): Promise<RegionCacheParameters>;
    getCustomOrderIdSeparator(provider: Provider, regionId: string): Promise<string>;
    private generateRandomId;
    generateCustomOrderId(provider: Provider, regionId: string): Promise<string>;
    generateRandomString(characters: string, length: number): string;
    getBuyUrl(provider: Provider, regionId: string, paymentId: string, crypto: string, fiat: string, amount: number | string, receiver: string): Promise<BuyAction>;
    getSellUrl(provider: Provider, regionId: string, paymentId: string, crypto: string, fiat: string, amount: number, receiver: string): Promise<BuyAction>;
    private getBuyWidgetInformation;
    private getSellWidgetInformation;
    private getFiatAmountFromCryptoAmount;
    getRedirectionUrl(provider: string): string;
    getAllFiatCurrencies(regionId: string, abortController?: AbortController): Promise<FiatCurrency[]>;
    getAllCryptoCurrencies(regionId: string, abortController?: AbortController): Promise<CryptoCurrency[]>;
    getLight(action: ProviderAction, regionId: string, paymentMethodIds?: string[], fiatCurrencyId?: string, cryptoCurrencyId?: string, multiplePayments?: boolean, abortController?: AbortController): Promise<any>;
}
