"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProviderAction = void 0;
const ProviderList_1 = __importDefault(require("../providers/ProviderList"));
const API_1 = require("../API");
const Utils_1 = __importDefault(require("../Utils"));
const CountryCache_1 = require("./CountryCache");
const BuyAction_1 = __importDefault(require("./BuyAction"));
const uuid_1 = require("uuid");
const SdkParam_1 = __importDefault(require("../SdkParam"));
var ProviderAction;
(function (ProviderAction) {
    ProviderAction["unknown"] = "";
    ProviderAction["buy"] = "buy";
    ProviderAction["recurringBuy"] = "recurring-buy";
    ProviderAction["sell"] = "sell";
})(ProviderAction = exports.ProviderAction || (exports.ProviderAction = {}));
class RegionsService {
    static async create(axios, logger, sdk, sdkParameters) {
        RegionsService.instanceCount++;
        if (RegionsService.instanceCount >= 2) {
            const extraInstanceCount = RegionsService.instanceCount - 1;
            console.warn(`${extraInstanceCount} other instance${extraInstanceCount >= 2 ? 's' : ''} of the regions service already exist${extraInstanceCount <= 1 ? 's' : ''}. The regions service is likely being used by multiple SDK instance. This might result in increased network activity and poor performance. If possible, OnRampSdk.getSdk().regions() should only be called once in your application or per webpage, as it contains cached data.`);
        }
        const newInstance = new RegionsService(axios, logger, sdkParameters);
        await newInstance.init(sdk);
        return newInstance;
    }
    constructor(axios, logger, sdkParameters) {
        this.axios = axios;
        this.logger = logger;
        this.sdkParameters = sdkParameters;
        this.disabledLimit = {
            minAmount: -Infinity,
            maxAmount: Infinity,
            feeDynamicRate: 0,
            feeFixedRate: 0,
            quickAmounts: [],
        };
        this.countryCache = new Map();
    }
    async reset(sdk) {
        this.cachedCountries.clear();
        this.countryCache.clear();
        await this.init(sdk);
    }
    async downloadCachedCountries() {
        const url = '/regions/countries';
        this.logger.log(`Querying URL ${url}`);
        this.cachedCountries = await Utils_1.default.downloadAsMap(this.axios, url);
    }
    async init(sdk) {
        await this.downloadCachedCountries();
        this.providers = this.buildProviders(sdk);
    }
    buildProviders(sdk) {
        const providers = new ProviderList_1.default(sdk, this.logger);
        return providers;
    }
    getCacheId(action, regionId, paymentIds, fiatId, cryptoId) {
        return `${action}-${regionId}-${paymentIds === null || paymentIds === void 0 ? void 0 : paymentIds.join(',')}-${fiatId}-${cryptoId}`;
    }
    async getCountryCache(action, regionId, paymentIds, fiatId, cryptoId, abortController) {
        const cacheId = this.getCacheId(action, regionId, paymentIds, fiatId, cryptoId);
        let result = this.countryCache.get(cacheId);
        if (!result) {
            result = await Utils_1.default.try(async () => await CountryCache_1.CountryCache.Create(this.logger, this.axios, this.sdkParameters.environment.regions, action, regionId, paymentIds, fiatId, cryptoId, abortController));
            this.countryCache.set(cacheId, result);
        }
        else if (result.expirationDate <= new Date()) {
            try {
                result = await Utils_1.default.try(async () => await CountryCache_1.CountryCache.Create(this.logger, this.axios, this.sdkParameters.environment.regions, action, regionId, paymentIds, fiatId, cryptoId, abortController));
                if (result) {
                    this.countryCache.set(cacheId, result);
                }
            }
            catch (_a) {
            }
        }
        return result;
    }
    async getCountries() {
        if (this.cachedCountries.size === 0) {
            await this.downloadCachedCountries();
        }
        return [...this.cachedCountries.values()];
    }
    async getSellCountries() {
        if (this.cachedCountries.size === 0) {
            await this.downloadCachedCountries();
        }
        return [...this.cachedCountries.values()].reduce((filteredRegions, country) => {
            var _a, _b;
            const sellSupported = (_a = country === null || country === void 0 ? void 0 : country.support) === null || _a === void 0 ? void 0 : _a.sell;
            const filteredStates = (_b = country === null || country === void 0 ? void 0 : country.states) === null || _b === void 0 ? void 0 : _b.filter((state) => { var _a; return (_a = state === null || state === void 0 ? void 0 : state.support) === null || _a === void 0 ? void 0 : _a.sell; });
            if (sellSupported || filteredStates) {
                filteredRegions.push(Object.assign(Object.assign({}, country), { states: filteredStates }));
            }
            return filteredRegions;
        }, []);
    }
    async getPaymentMethods(regionId, abortController) {
        Utils_1.default.checkParameters({ regionId });
        const payments = (await this.getCountryCache(ProviderAction.buy, regionId, null, null, null, abortController)).cachedPayments;
        return payments;
    }
    async getPaymentMethodsForCrypto(regionId, crypto, fiat, abortController) {
        Utils_1.default.checkParameters({ regionId, fiat });
        const cache = await this.getCountryCache(ProviderAction.buy, regionId, null, fiat, crypto, abortController);
        return cache.cachedPayments;
    }
    async getSellPaymentMethodsForCrypto(regionId, crypto, fiat, abortController) {
        Utils_1.default.checkParameters({ regionId, fiat });
        const cache = await this.getCountryCache(ProviderAction.sell, regionId, null, fiat, crypto, abortController);
        return cache.cachedPayments;
    }
    async getSellPaymentMethods(regionId, abortController) {
        Utils_1.default.checkParameters({ regionId });
        return (await this.getCountryCache(ProviderAction.sell, regionId, null, null, null, abortController)).cachedPayments;
    }
    async getPaymentMethod(regionId, id, action) {
        Utils_1.default.checkParameters({ regionId, id });
        const normalizedId = id.startsWith('/payments/') ? id : `/payments/${id}`;
        return (await this.getCountryCache(action, regionId, [normalizedId], null, null, null)).cachedPayments.find((p) => p.id === normalizedId);
    }
    async getDefaultFiatCurrency(regionId, paymentMethods) {
        Utils_1.default.checkParameters({ regionId });
        const countries = [...this.cachedCountries.values()];
        const fiats = [
            ...(await this.getCountryCache(ProviderAction.buy, regionId, paymentMethods, null, null, null)).cachedFiatCurrencies.values(),
        ];
        return this.getDefaultFiatCurrencySync(countries, fiats, regionId, paymentMethods);
    }
    getDefaultFiatCurrencySync(countries, fiats, regionId, paymentMethods) {
        const country = countries.find((c) => c.id === regionId ||
            (c.states && c.states.find((s) => s.id === regionId)));
        for (const c of country.currencies) {
            const defaultFiat = fiats.find((f) => f.id === c);
            if (defaultFiat)
                return defaultFiat;
        }
        const fallbackFiat = fiats.find((f) => f.id === `/currencies/fiat/usd` || f.id === `/currencies/fiat/eur`);
        if (fallbackFiat)
            return fallbackFiat;
        return (fiats === null || fiats === void 0 ? void 0 : fiats.length) ? fiats[0] : null;
    }
    async getDefaultSellFiatCurrency(regionId, paymentMethods) {
        Utils_1.default.checkParameters({ regionId });
        const countries = [...this.cachedCountries.values()];
        const fiats = [
            ...(await this.getCountryCache(ProviderAction.sell, regionId, paymentMethods, null, null, null)).cachedFiatCurrencies.values(),
        ];
        return this.getDefaultSellFiatCurrencySync(countries, fiats, regionId, paymentMethods);
    }
    getDefaultSellFiatCurrencySync(countries, fiats, regionId, paymentMethods) {
        const country = countries.find((c) => c.id === regionId ||
            (c.states && c.states.find((s) => s.id === regionId)));
        for (const c of country.currencies) {
            const defaultFiat = fiats.find((f) => f.id === c);
            if (defaultFiat)
                return defaultFiat;
        }
        const fallbackFiat = fiats.find((f) => f.id === `/currencies/fiat/usd` || f.id === `/currencies/fiat/eur`);
        if (fallbackFiat)
            return fallbackFiat;
        return (fiats === null || fiats === void 0 ? void 0 : fiats.length) ? fiats[0] : null;
    }
    async getCryptoCurrencies(regionId, paymentMethodIds, fiatCurrencyId, abortController) {
        Utils_1.default.checkParameters({ regionId, paymentMethodIds });
        const countryCache = await this.getCountryCache(ProviderAction.buy, regionId, paymentMethodIds, fiatCurrencyId, null, abortController);
        return this.getCryptoCurrenciesSync(countryCache, paymentMethodIds, fiatCurrencyId);
    }
    async getNetworkDetails() {
        const response = (await this.axios.get('/regions/network-details'));
        return response === null || response === void 0 ? void 0 : response.data;
    }
    async getSellCryptoCurrencies(regionId, paymentMethodIds, fiatCurrencyId, abortController) {
        Utils_1.default.checkParameters({ regionId, paymentMethodIds });
        const countryCache = await this.getCountryCache(ProviderAction.sell, regionId, paymentMethodIds, fiatCurrencyId, null, abortController);
        return this.getSellCryptoCurrenciesSync(countryCache, paymentMethodIds, fiatCurrencyId);
    }
    getCryptoCurrenciesSync(countryCache, paymentMethodIds, fiatCurrencyId) {
        if (paymentMethodIds.length > 0 &&
            !countryCache.cachedPayments.some((p) => paymentMethodIds.includes(p.id))) {
            return [];
        }
        if (!!fiatCurrencyId &&
            !countryCache.cachedFiatCurrencies.has(fiatCurrencyId)) {
            return [];
        }
        return Array.from(countryCache.cachedCryptoCurrencies.values());
    }
    getSellCryptoCurrenciesSync(countryCache, paymentMethodIds, fiatCurrencyId) {
        if (paymentMethodIds.length > 0 &&
            !countryCache.cachedPayments.some((p) => paymentMethodIds.includes(p.id))) {
            return [];
        }
        if (!!fiatCurrencyId &&
            !countryCache.cachedFiatCurrencies.has(fiatCurrencyId)) {
            return [];
        }
        return Array.from(countryCache.cachedCryptoCurrencies.values());
    }
    async getCryptoCurrency(regionId, cryptoId) {
        Utils_1.default.checkParameters({ regionId, cryptoId: cryptoId });
        return (await this.getCountryCache(null, regionId, [], null, cryptoId, null)).cachedCryptoCurrencies.get(cryptoId);
    }
    async getFiatCurrencies(regionId, paymentMethodIds, abortController) {
        Utils_1.default.checkParameters({ regionId, paymentMethodIds });
        return Array.from((await this.getCountryCache(ProviderAction.buy, regionId, paymentMethodIds, null, null, abortController)).cachedFiatCurrencies.values());
    }
    async getSellFiatCurrencies(regionId, paymentMethodIds, abortController) {
        Utils_1.default.checkParameters({ regionId, paymentMethodIds });
        return Array.from((await this.getCountryCache(ProviderAction.sell, regionId, paymentMethodIds, null, null, abortController)).cachedFiatCurrencies.values());
    }
    async getFiatCurrency(regionId, fiatId) {
        Utils_1.default.checkParameters({ regionId, cryptoId: fiatId });
        return (await this.getCountryCache(null, regionId, [], null, fiatId, null)).cachedFiatCurrencies.get(fiatId);
    }
    getProvidersWithoutAmountSync(providersInCountry, paymentMethods, crypto, fiat) {
        const isProviderSupportingPaymentMethods = (provider) => {
            if (paymentMethods.length === 0)
                return true;
            return paymentMethods.some((method) => provider.supportedPaymentMethods.some((payment) => payment.id === method));
        };
        const isCryptoSupported = (cryptoCurrency) => {
            if (paymentMethods.length === 0)
                return true;
            return !paymentMethods.some((method) => cryptoCurrency.excludedFiatAndPaymentMethods.some((fp) => fp.excludedFiat === fiat && fp.excludedPaymentMethod === method));
        };
        const isFiatSupported = (fiatCurrency) => {
            if (paymentMethods.length === 0)
                return true;
            return !paymentMethods.some((method) => fiatCurrency.excludedPaymentMethods.includes(method));
        };
        const providersWithMethod = providersInCountry.filter((provider) => isProviderSupportingPaymentMethods(provider));
        const providersWithPaymentAndFiat = providersWithMethod.filter((p) => {
            return p.supportedPaymentMethods.some((payment) => !payment.supportedCurrency ||
                payment.supportedCurrency.includes(fiat));
        });
        const providersWithCrypto = providersWithPaymentAndFiat.filter((p) => p.supportedCryptoCurrencies.filter((c) => c.id === crypto &&
            !c.excludedFiat.includes(fiat) &&
            isCryptoSupported(c)).length);
        const providersWithFiat = providersWithCrypto.filter((p) => p.supportedFiatCurrencies.filter((f) => f.id === fiat && isFiatSupported(f)).length);
        return providersWithFiat;
    }
    async getLimits(regionId, paymentMethods, crypto, fiat, abortController) {
        Utils_1.default.checkParameters({ regionId, paymentMethods, crypto, fiat });
        const cache = await this.getCountryCache(ProviderAction.buy, regionId, paymentMethods, fiat, crypto, abortController);
        if (!cache.limits) {
            const limit = this.disabledLimit;
            limit.quickAmounts = this.getQuickAmounts(fiat, limit.minAmount, limit.maxAmount);
            return limit;
        }
        else {
            return {
                minAmount: cache.limits.minAmount,
                maxAmount: cache.limits.maxAmount,
                feeDynamicRate: cache.limits.feeDynamicRate,
                feeFixedRate: cache.limits.feeFixedRate,
                quickAmounts: this.getQuickAmounts(fiat, cache.limits.minAmount, cache.limits.maxAmount),
            };
        }
    }
    async getSellLimits(regionId, paymentMethods, crypto, fiat) {
        Utils_1.default.checkParameters({ regionId, paymentMethods, crypto, fiat });
        const cache = await this.getCountryCache(ProviderAction.sell, regionId, paymentMethods, fiat, crypto, new AbortController());
        if (!cache.limits) {
            const limit = this.disabledLimit;
            limit.quickAmounts = null;
            return limit;
        }
        else {
            return {
                minAmount: cache.limits.minAmount,
                maxAmount: cache.limits.maxAmount,
                feeDynamicRate: 0,
                feeFixedRate: 0,
                quickAmounts: null,
            };
        }
    }
    async getQuotes(regionId, paymentMethods, crypto, fiat, amount, receiver, abortController) {
        return this.makeQuoteCall(regionId, paymentMethods, crypto, fiat, amount, receiver, ProviderAction.buy, abortController);
    }
    async getQuotesWithoutCache(regionId, paymentMethods, crypto, fiat, amount, receiver, action, abortController) {
        var _a;
        Utils_1.default.checkParameters({
            regionId,
            paymentMethods,
            crypto,
            fiat,
        });
        let quotes;
        let sorted;
        let customActions;
        try {
            const { success, error, sorted: sortMetadata, customActions: customActionsData, } = await this.getAllQuotesFromApiWithoutCache(regionId, paymentMethods, crypto, fiat, amount, receiver, action, abortController);
            quotes = [...success, ...error];
            sorted = sortMetadata;
            customActions = customActionsData;
            if (action === ProviderAction.buy) {
                customActions = customActionsData.map((paymentCustomAction) => {
                    var _a;
                    paymentCustomAction.buy.provider = (_a = success.find((q) => q.provider === paymentCustomAction.buy.providerId)) === null || _a === void 0 ? void 0 : _a.providerInfo;
                    return paymentCustomAction;
                });
            }
        }
        catch (err) {
            if ((_a = abortController === null || abortController === void 0 ? void 0 : abortController.signal) === null || _a === void 0 ? void 0 : _a.aborted) {
                throw err;
            }
        }
        let marketPrice;
        try {
            marketPrice = await this.getExchangeRateFromAPI(fiat, crypto);
        }
        catch (err) {
            this.logger.log(`Failed to get marketPrice from api: ${err.message}`);
        }
        const quotesWithMarketPrice = quotes === null || quotes === void 0 ? void 0 : quotes.map((quoteObj) => {
            if (quoteObj === null || quoteObj === void 0 ? void 0 : quoteObj.error) {
                return quoteObj;
            }
            const quoteResponse = quoteObj;
            if (marketPrice) {
                quoteResponse.amountOutInFiat = marketPrice * quoteResponse.amountOut;
            }
            return quoteResponse;
        });
        return { quotes: quotesWithMarketPrice, sorted, customActions };
    }
    async makeQuoteCall(regionId, paymentMethods, crypto, fiat, amount, receiver, action, abortController) {
        var _a;
        Utils_1.default.checkParameters({
            regionId,
            paymentMethods,
            crypto,
            fiat,
        });
        let quotes;
        let sorted;
        let customActions;
        try {
            const { success, error, sorted: sortMetadata, customActions: customActionsData, } = await this.getAllQuotesFromApi(regionId, paymentMethods, crypto, fiat, amount, receiver, action, abortController);
            quotes = [...success, ...error];
            sorted = sortMetadata;
            customActions = customActionsData;
        }
        catch (err) {
            if ((_a = abortController === null || abortController === void 0 ? void 0 : abortController.signal) === null || _a === void 0 ? void 0 : _a.aborted) {
                throw err;
            }
        }
        let marketPrice;
        try {
            marketPrice = await this.getExchangeRateFromAPI(fiat, crypto);
        }
        catch (err) {
            this.logger.log(`Failed to get marketPrice from api: ${err.message}`);
        }
        const quotesWithMarketPrice = quotes === null || quotes === void 0 ? void 0 : quotes.map((quoteObj) => {
            if (quoteObj === null || quoteObj === void 0 ? void 0 : quoteObj.error) {
                return quoteObj;
            }
            const quoteResponse = quoteObj;
            if (marketPrice) {
                quoteResponse.amountOutInFiat = marketPrice * quoteResponse.amountOut;
            }
            return quoteResponse;
        });
        const quotesWithLogos = quotesWithMarketPrice === null || quotesWithMarketPrice === void 0 ? void 0 : quotesWithMarketPrice.map((q) => {
            Utils_1.default.setProviderAbsoluteUrls(this.sdkParameters.environment.regions, q.provider);
            return q;
        });
        const customActionsWithLogos = customActions === null || customActions === void 0 ? void 0 : customActions.map((cA) => {
            Utils_1.default.setProviderAbsoluteUrls(this.sdkParameters.environment.regions, cA.buy.provider);
            return cA;
        });
        return {
            quotes: quotesWithLogos,
            sorted,
            customActions: customActionsWithLogos,
        };
    }
    async getAllQuotesFromApi(regionId, paymentMethods, crypto, fiat, amount, receiver, action, abortController) {
        Utils_1.default.checkParameters({
            regionId,
            paymentMethods,
            crypto,
            fiat,
        });
        const url = new URL(`${Utils_1.default.trimUrl(this.sdkParameters.environment.orders)}`);
        url.pathname =
            action === ProviderAction.buy
                ? 'providers/all/quote'
                : 'providers/all/sell-quote';
        url.searchParams.set('regionId', regionId);
        url.searchParams.set('cryptoCurrencyId', crypto);
        url.searchParams.set('fiatCurrencyId', fiat);
        url.searchParams.set('amount', amount.toString());
        if (paymentMethods) {
            paymentMethods === null || paymentMethods === void 0 ? void 0 : paymentMethods.forEach((p, index) => {
                url.searchParams.set(`paymentMethodId[${index}]`, p);
            });
        }
        if (receiver) {
            url.searchParams.set('walletAddress', receiver);
        }
        const response = (await this.axios.get(url.toString(), {
            signal: abortController.signal,
        }));
        const quotesData = response === null || response === void 0 ? void 0 : response.data;
        const successQuotes = await Promise.all(quotesData.success.map(async (quote) => {
            const providerOfQuote = this.providers.get(quote.provider);
            const formattedQuote = await providerOfQuote.formatQuote(quote, quote.providerInfo, regionId, quote.quote.paymentMethod, crypto, fiat, amount.toString(), action, receiver);
            Utils_1.default.setProviderAbsoluteUrls(this.sdkParameters.environment.regions, formattedQuote.provider);
            return formattedQuote;
        }));
        const errorQuotes = quotesData.error.map((quote) => {
            return {
                error: true,
                message: 'An unexpected error occured',
                technicalDetails: Utils_1.default.stringify(quote.err),
                provider: quote.providerInfo,
            };
        });
        return {
            success: successQuotes,
            error: errorQuotes,
            sorted: quotesData.sorted,
            customActions: quotesData.customActions,
        };
    }
    async getAllQuotesFromApiWithoutCache(regionId, paymentMethods, crypto, fiat, amount, receiver, action, abortController) {
        Utils_1.default.checkParameters({
            regionId,
            paymentMethods,
            crypto,
            fiat,
        });
        const url = new URL(`${Utils_1.default.trimUrl(this.sdkParameters.environment.orders)}`);
        url.pathname =
            action === ProviderAction.buy
                ? 'providers/all/quote'
                : 'providers/all/sell-quote';
        url.searchParams.set('regionId', regionId);
        url.searchParams.set('cryptoCurrencyId', crypto);
        url.searchParams.set('fiatCurrencyId', fiat);
        if (amount) {
            url.searchParams.set('amount', amount.toString());
        }
        if (paymentMethods) {
            paymentMethods === null || paymentMethods === void 0 ? void 0 : paymentMethods.forEach((p, index) => {
                url.searchParams.set(`paymentMethodId[${index}]`, p);
            });
        }
        if (receiver) {
            url.searchParams.set('walletAddress', receiver);
        }
        const response = (await this.axios.get(url.toString(), {
            signal: abortController.signal,
        }));
        const quotesData = response === null || response === void 0 ? void 0 : response.data;
        const successQuotes = await Promise.all(quotesData.success.map((quote) => {
            const providerOfQuote = this.providers.get(quote.provider);
            return providerOfQuote.formatQuote(quote, quote.providerInfo, regionId, quote.quote.paymentMethod, crypto, fiat, amount.toString(), action, receiver);
        }));
        const errorQuotes = quotesData.error.map((quote) => {
            return {
                error: true,
                message: 'An unexpected error occured',
                technicalDetails: Utils_1.default.stringify(quote.err),
                provider: quote.providerInfo,
            };
        });
        return {
            success: successQuotes,
            error: errorQuotes,
            sorted: quotesData.sorted,
            customActions: quotesData.customActions,
        };
    }
    async getExchangeRateFromAPI(fiat, crypto) {
        var _a;
        const baseUrl = this.sdkParameters.environment.regions.endsWith('/')
            ? this.sdkParameters.environment.regions.substring(0, this.sdkParameters.environment.regions.length - 1)
            : this.sdkParameters.environment.regions;
        const url = new URL(`${baseUrl}${crypto}/amount`);
        url.searchParams.set('value', '1');
        url.searchParams.set('fiat', fiat);
        const response = (await this.axios.get(url.toString()));
        return (_a = response === null || response === void 0 ? void 0 : response.data) === null || _a === void 0 ? void 0 : _a.value;
    }
    async getRankingDataFromApi() {
        try {
            const baseUrl = this.sdkParameters.environment.orders.endsWith('/')
                ? this.sdkParameters.environment.orders.substring(0, this.sdkParameters.environment.orders.length - 1)
                : this.sdkParameters.environment.orders;
            const url = new URL(`${baseUrl}/providers/all/rankings`);
            const response = (await this.axios.get(url.toString()));
            return response === null || response === void 0 ? void 0 : response.data;
        }
        catch (_a) {
            return null;
        }
    }
    async getSellCustomActions(regionId, paymentMethods, crypto, fiat, amount, abortController) {
        Utils_1.default.checkParameters({
            regionId,
            paymentMethods,
            crypto,
            fiat,
        });
        const amountAsNumber = typeof amount === 'string' ? parseFloat(amount) : amount;
        const limits = await this.getSellLimits(regionId, paymentMethods, crypto, fiat);
        if (amountAsNumber < limits.minAmount &&
            amountAsNumber > limits.maxAmount) {
            return [];
        }
        const cache = await this.getCountryCache(ProviderAction.sell, regionId, paymentMethods, fiat, crypto, abortController);
        const cachePaymentMethods = Array.from(cache.cachedPayments.values());
        const customActions = cachePaymentMethods.filter((p) => p.customAction && p.sellEnabled);
        return customActions;
    }
    async getCustomActions(regionId, paymentMethods, crypto, fiat, amount, abortController) {
        Utils_1.default.checkParameters({
            regionId,
            paymentMethods,
            crypto,
            fiat,
        });
        const amountAsNumber = typeof amount === 'string' ? parseFloat(amount) : amount;
        const limits = await this.getLimits(regionId, paymentMethods, crypto, fiat);
        if (amountAsNumber < limits.minAmount &&
            amountAsNumber > limits.maxAmount) {
            return [];
        }
        const cache = await this.getCountryCache(ProviderAction.buy, regionId, paymentMethods, fiat, crypto, abortController);
        const cachePaymentMethods = Array.from(cache.cachedPayments.values());
        const customActions = cachePaymentMethods.filter((p) => p.customAction);
        return customActions;
    }
    async getSellQuotes(regionId, paymentMethods, crypto, fiat, amount, receiver, abortController) {
        return this.makeQuoteCall(regionId, paymentMethods, crypto, fiat, amount, receiver, ProviderAction.sell, abortController);
    }
    getQuickAmounts(fiat, min, max) {
        const allowedFiat = [
            '/currencies/fiat/eur',
            '/currencies/fiat/gbp',
            '/currencies/fiat/usd',
        ];
        if (!allowedFiat.includes(fiat)) {
            return [];
        }
        const suggestion = [50, 100, 200, 400];
        if (suggestion[0] >= min && suggestion[3] <= max) {
            return suggestion;
        }
        return [];
    }
    standardizeQuote(quote, fiat, crypto) {
        quote.fiat = fiat;
        quote.crypto = crypto;
        quote.networkFee = quote.networkFee || 0;
        quote.providerFee = quote.providerFee || 0;
        quote.amountIn = quote.amountIn || 0;
        quote.amountOut = quote.amountOut || 0;
        quote.exchangeRate = this.getExchangeRate(quote);
        return quote;
    }
    standardizeSellQuote(quote, fiat, crypto) {
        quote.fiat = fiat;
        quote.crypto = crypto;
        quote.networkFee = quote.networkFee || 0;
        quote.providerFee = quote.providerFee || 0;
        quote.amountIn = quote.amountIn || 0;
        quote.amountOut = quote.amountOut || 0;
        quote.exchangeRate = this.getSellExchangeRate(quote);
        return quote;
    }
    getExchangeRate(quote) {
        if (quote.exchangeRate) {
            return quote.exchangeRate;
        }
        if (!quote.amountIn || !quote.amountOut) {
            return null;
        }
        const fees = [quote.providerFee, quote.networkFee, quote.extraFee]
            .filter((fee) => typeof fee === 'number')
            .reduce((sum, value) => sum + value, 0);
        return (quote.amountIn - fees) / quote.amountOut;
    }
    getSellExchangeRate(quote) {
        if (quote.exchangeRate) {
            return quote.exchangeRate;
        }
        if (!quote.amountIn || !quote.amountOut) {
            return null;
        }
        const fees = [quote.providerFee, quote.networkFee, quote.extraFee]
            .filter((fee) => typeof fee === 'number')
            .reduce((sum, value) => sum + value, 0);
        return (quote.amountIn - fees) / quote.amountOut;
    }
    async getParameters(regionId) {
        Utils_1.default.checkParameters({ regionId });
        return (await this.getCountryCache(null, regionId, [], null, null, new AbortController())).cachedParameters;
    }
    async getCustomOrderIdSeparator(provider, regionId) {
        if (provider.features.buy.orderCustomIdSeparator) {
            return provider.features.buy.orderCustomIdSeparator;
        }
        else {
            const defaultSeparator = (await this.getParameters(regionId))
                .defaultOrderCustomIdSeparator;
            if (defaultSeparator) {
                return defaultSeparator;
            }
            else {
                return '-';
            }
        }
    }
    generateRandomId(provider) {
        const customIdType = provider.features.buy.orderCustomId;
        if (customIdType === API_1.ProviderBuyFeatureOrderCustomIdEnum.Guid) {
            return (0, uuid_1.v4)().replace('-', '');
        }
        else if (customIdType === API_1.ProviderBuyFeatureOrderCustomIdEnum.Digits10) {
            return this.generateRandomString('0123456789', 10);
        }
        else if (customIdType === API_1.ProviderBuyFeatureOrderCustomIdEnum.Alpha64) {
            return this.generateRandomString('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789', 64);
        }
        else {
            return this.generateRandomString('0123456789', 10);
        }
    }
    async generateCustomOrderId(provider, regionId) {
        const randomString = this.generateRandomId(provider);
        if (provider.features.buy.orderCustomIdExpiration) {
            const separator = await this.getCustomOrderIdSeparator(provider, regionId);
            const expiration = new Date().getTime() +
                provider.features.buy.orderCustomIdExpiration * 60 * 1000;
            return `${provider.id}/orders/${randomString}${separator}${expiration}`;
        }
        else {
            return `${provider.id}/orders/${randomString}`;
        }
    }
    generateRandomString(characters, length) {
        const charactersLength = characters.length;
        let result = '';
        for (let i = 0; i < length; i++) {
            result += characters.charAt(Math.floor(Math.random() * charactersLength));
        }
        return result;
    }
    async getBuyUrl(provider, regionId, paymentId, crypto, fiat, amount, receiver) {
        const paymentMethod = await this.getPaymentMethod(regionId, paymentId, ProviderAction.buy);
        const buyAction = BuyAction_1.default.build((browser, redirectUrl) => this.getBuyWidgetInformation(provider, regionId, paymentMethod, crypto, fiat, amount, receiver, redirectUrl, browser), provider, paymentMethod);
        return buyAction;
    }
    async getSellUrl(provider, regionId, paymentId, crypto, fiat, amount, receiver) {
        const paymentMethod = await this.getPaymentMethod(regionId, paymentId, ProviderAction.sell);
        const buyAction = BuyAction_1.default.build((browser, redirectUrl) => this.getSellWidgetInformation(provider, regionId, paymentMethod, crypto, fiat, amount, receiver, redirectUrl, browser), provider, paymentMethod);
        return buyAction;
    }
    async getBuyWidgetInformation(provider, regionId, paymentMethod, crypto, fiat, amount, receiver, redirectUrl, browser) {
        var _a, _b, _c;
        const baseUrl = this.sdkParameters.environment.orders.endsWith('/')
            ? this.sdkParameters.environment.orders.substring(0, this.sdkParameters.environment.orders.length - 1)
            : this.sdkParameters.environment.orders;
        const url = new URL(`${baseUrl}${provider.id}/buy-widget`);
        url.searchParams.set('regionId', regionId);
        url.searchParams.set('paymentMethodId', paymentMethod.id);
        url.searchParams.set('cryptoCurrencyId', crypto);
        url.searchParams.set('fiatCurrencyId', fiat);
        url.searchParams.set('amount', amount.toString());
        url.searchParams.set('walletAddress', receiver);
        url.searchParams.set('redirectUrl', redirectUrl);
        if (provider.features.buy.redirection ===
            API_1.ProviderBuyFeatureRedirectionEnum.HttpRedirection) {
            let orderCustomId = this.generateRandomId(provider);
            const result = (await this.axios.get(url.toString()));
            if (result.status === 200) {
                return {
                    url: result.data.url,
                    browser: browser,
                    orderId: orderCustomId,
                };
            }
            else {
                if ((_b = (_a = provider === null || provider === void 0 ? void 0 : provider.features) === null || _a === void 0 ? void 0 : _a.buy) === null || _b === void 0 ? void 0 : _b.orderCustomId) {
                    orderCustomId = await this.generateCustomOrderId(provider, regionId);
                    url.searchParams.set('orderId', orderCustomId);
                }
                return {
                    url: url.toString(),
                    browser: browser,
                    orderId: orderCustomId,
                };
            }
        }
        else if (provider.features.buy.redirection ===
            API_1.ProviderBuyFeatureRedirectionEnum.JsonRedirection) {
            const result = (_c = (await this.axios.get(url.toString()))) === null || _c === void 0 ? void 0 : _c.data;
            if (!(result === null || result === void 0 ? void 0 : result.url)) {
                this.logger.log(`Buy URL could not be generated`);
                return null;
            }
            return result;
        }
        else {
            throw new Error(`Unsupported redirection type: ${provider.features.buy.redirection}`);
        }
    }
    async getSellWidgetInformation(provider, regionId, paymentMethod, crypto, fiat, amount, receiver, redirectUrl, browser) {
        var _a, _b, _c;
        const baseUrl = this.sdkParameters.environment.orders.endsWith('/')
            ? this.sdkParameters.environment.orders.substring(0, this.sdkParameters.environment.orders.length - 1)
            : this.sdkParameters.environment.orders;
        const url = new URL(`${baseUrl}${provider.id}/sell-widget`);
        url.searchParams.set('regionId', regionId);
        url.searchParams.set('paymentMethodId', paymentMethod.id);
        url.searchParams.set('cryptoCurrencyId', crypto);
        url.searchParams.set('fiatCurrencyId', fiat);
        url.searchParams.set('amount', amount.toString());
        url.searchParams.set('walletAddress', receiver);
        url.searchParams.set('redirectUrl', redirectUrl);
        if (provider.features.buy.redirection ===
            API_1.ProviderBuyFeatureRedirectionEnum.HttpRedirection) {
            let orderCustomId = this.generateRandomId(provider);
            const result = (await this.axios.get(url.toString()));
            if (result.status === 200) {
                return {
                    url: result.data.url,
                    browser: browser,
                    orderId: orderCustomId,
                };
            }
            else {
                if ((_b = (_a = provider === null || provider === void 0 ? void 0 : provider.features) === null || _a === void 0 ? void 0 : _a.buy) === null || _b === void 0 ? void 0 : _b.orderCustomId) {
                    orderCustomId = await this.generateCustomOrderId(provider, regionId);
                    url.searchParams.set('orderId', orderCustomId);
                }
                return {
                    url: url.toString(),
                    browser: browser,
                    orderId: orderCustomId,
                };
            }
        }
        else if (provider.features.buy.redirection ===
            API_1.ProviderBuyFeatureRedirectionEnum.JsonRedirection) {
            const result = (_c = (await this.axios.get(url.toString()))) === null || _c === void 0 ? void 0 : _c.data;
            if (!(result === null || result === void 0 ? void 0 : result.url)) {
                this.logger.log(`Buy URL could not be generated`);
                return null;
            }
            return result;
        }
        else {
            throw new Error(`Unsupported redirection type: ${provider.features.buy.redirection}`);
        }
    }
    async getFiatAmountFromCryptoAmount(fiatCurrencyId, cryptoCurrencyId, cryptoAmount) {
        var _a;
        const url = `${cryptoCurrencyId}/amount?value=${encodeURIComponent(cryptoAmount)}&fiat=${fiatCurrencyId}`;
        return ((_a = (await this.axios.get(url.toString()))) === null || _a === void 0 ? void 0 : _a.data).value;
    }
    getRedirectionUrl(provider) {
        return `${Utils_1.default.trimUrl(this.sdkParameters.environment.orders)}${provider}/redirect`;
    }
    async getAllFiatCurrencies(regionId, abortController) {
        const allFiat = Array.from((await this.getCountryCache(null, regionId, [], null, null, abortController)).cachedFiatCurrencies.values());
        return allFiat;
    }
    async getAllCryptoCurrencies(regionId, abortController) {
        const allCrypto = Array.from((await this.getCountryCache(null, regionId, [], null, null, abortController)).cachedCryptoCurrencies.values());
        return allCrypto;
    }
    async getLight(action, regionId, paymentMethodIds, fiatCurrencyId, cryptoCurrencyId, multiplePayments, abortController) {
        const result = await Utils_1.default.try(async () => {
            const axiosResponse = await this.axios.get(regionId + '/light', {
                params: {
                    payment: paymentMethodIds === null || paymentMethodIds === void 0 ? void 0 : paymentMethodIds.join(','),
                    fiat: fiatCurrencyId,
                    crypto: cryptoCurrencyId,
                    action: action,
                    multiplePayments: multiplePayments,
                },
                signal: abortController === null || abortController === void 0 ? void 0 : abortController.signal,
            });
            return axiosResponse.data;
        });
        return result;
    }
}
RegionsService.instanceCount = 0;
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "reset", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getPaymentMethods", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: false })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getPaymentMethodsForCrypto", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: false })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellPaymentMethodsForCrypto", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellPaymentMethods", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, String]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getPaymentMethod", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getDefaultFiatCurrency", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Array, Array, String, Array]),
    __metadata("design:returntype", Object)
], RegionsService.prototype, "getDefaultFiatCurrencySync", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getDefaultSellFiatCurrency", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Array, Array, String, Array]),
    __metadata("design:returntype", Object)
], RegionsService.prototype, "getDefaultSellFiatCurrencySync", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getCryptoCurrencies", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellCryptoCurrencies", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getCryptoCurrency", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getFiatCurrencies", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellFiatCurrencies", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getFiatCurrency", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getLimits", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellLimits", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __param(6, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getQuotes", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __param(6, (0, SdkParam_1.default)({ required: false })),
    __param(7, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, String, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getQuotesWithoutCache", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __param(6, (0, SdkParam_1.default)({ required: false })),
    __param(7, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, String, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "makeQuoteCall", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __param(6, (0, SdkParam_1.default)({ required: false })),
    __param(7, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, String, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getAllQuotesFromApi", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __param(6, (0, SdkParam_1.default)({ required: false })),
    __param(7, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, String, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getAllQuotesFromApiWithoutCache", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellCustomActions", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getCustomActions", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __param(6, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Array, String, String, Object, String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellQuotes", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: true })),
    __param(6, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, String, String, String, String, Object, String]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getBuyUrl", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: true })),
    __param(3, (0, SdkParam_1.default)({ required: true })),
    __param(4, (0, SdkParam_1.default)({ required: true })),
    __param(5, (0, SdkParam_1.default)({ required: true })),
    __param(6, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, String, String, String, String, Number, String]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getSellUrl", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], RegionsService.prototype, "getRedirectionUrl", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getAllFiatCurrencies", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getAllCryptoCurrencies", null);
__decorate([
    __param(0, (0, SdkParam_1.default)({ required: true })),
    __param(1, (0, SdkParam_1.default)({ required: true })),
    __param(2, (0, SdkParam_1.default)({ required: false })),
    __param(3, (0, SdkParam_1.default)({ required: false })),
    __param(4, (0, SdkParam_1.default)({ required: false })),
    __param(5, (0, SdkParam_1.default)({ required: false })),
    __param(6, (0, SdkParam_1.default)({ required: false })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, Array, String, String, Boolean, AbortController]),
    __metadata("design:returntype", Promise)
], RegionsService.prototype, "getLight", null);
exports.default = RegionsService;
